import type { AxiosInstance, AxiosRequestConfig } from "axios";
import { type QueryClient, type UseMutationOptions, type UseQueryOptions, type UseMutationResult, type UseQueryResult } from "react-query";
export declare type Assessment = {
    id?: string;
    name?: string;
    description?: string;
    questions?: AssessmentQuestion[];
};
export declare type AssessmentAnswer = {
    persistent?: boolean;
    id?: string;
    answer?: string;
    correctAnswer?: boolean;
};
export declare type AssessmentAnswerResponse = {
    id?: string;
    student?: Student;
    marked?: boolean;
    student_response?: string;
};
export declare type AssessmentQuestion = {
    id?: string;
    question?: string;
    explanation?: string;
    mark?: number;
    answers?: AssessmentAnswer[];
    is_long_form?: boolean;
};
export declare type AssessmentReports = {
    id?: string;
    student?: Student;
    status?: MarkingStatusEnum;
    total_marks?: number;
    percentage?: number;
    totalMarkQuestions?: number;
    responses?: AssessmentAnswerResponse[];
};
export declare type AssessmentStatus = {
    id?: string;
    completeStatus?: CompleteStatus;
    started_at?: string;
    completed_at?: string;
    student?: Student;
};
export declare type Classroom = {
    id?: string;
    name?: string;
    description?: string;
    subjects?: Subject[];
    level_grade?: Grade;
    teacher?: Teacher;
};
export declare type ClassroomSubscription = {
    id?: string;
    classroom?: Classroom;
    subscription?: UserSubscription;
};
export declare type CompleteStatus = "DOING" | "DONE";
export declare type CreateAssessmentAnswer = {
    question?: UUID;
    answer?: string;
    correct_answer?: boolean;
};
export declare type CreateAssessmentAnswerResponse = {
    answer?: UUID;
    report?: UUID;
    student_response?: string;
};
export declare type CreateAssessmentConsumable = {
    name?: string;
    description?: string;
    subject?: UUID;
};
export declare type CreateAssessmentGrading = {
    assessment?: UUID;
};
export declare type CreateAssessmentLongAnswerResponse = {
    question?: UUID;
    report?: UUID;
    student_response?: string;
};
export declare type CreateAssessmentQuestion = {
    assessment?: UUID;
    question?: string;
    explanation?: string;
    mark?: number;
    is_long_form?: boolean;
};
export declare type CreateAssessmentStatus = {
    assessment?: UUID;
};
export declare type CreateClassroomConsumable = {
    name?: string;
    description?: string;
    level_grade?: Grade;
};
export declare type CreateDocument = {
    name?: string;
    description?: string;
    file?: UUID;
    lesson?: UUID;
};
export declare type CreateExerciseAnswer = {
    question?: UUID;
    answer?: string;
    correct_answer?: boolean;
};
export declare type CreateExerciseAnswerResponse = {
    answer?: UUID;
    report?: UUID;
};
export declare type CreateExerciseConsumable = {
    name?: string;
    description?: string;
    lesson?: UUID;
};
export declare type CreateExerciseGrading = {
    exercise?: UUID;
};
export declare type CreateExerciseQuestion = {
    exercise?: UUID;
    question?: string;
    explanation?: string;
    mark?: number;
};
export declare type CreateExerciseStatus = {
    exercise?: UUID;
};
export declare type CreateFileConsumable = {
    name?: string;
    description?: string;
};
export declare type CreateFileResponse = {
    path?: URL;
    file?: string;
};
export declare type CreateLessonConsumable = {
    name?: string;
    description?: string;
    topic?: UUID;
};
export declare type CreateMedia = {
    name?: string;
    description?: string;
    file?: UUID;
    playlist?: UUID;
};
export declare type CreateNotesConsumable = {
    name?: string;
    description?: string;
    content?: string;
    lesson?: UUID;
};
export declare type CreatePlaylistConsumable = {
    name?: string;
    description?: string;
    lesson?: UUID;
    type?: PlaylistMediaEnum;
};
export declare type CreateSubjects = {
    name?: SubjectsEnum;
    description?: string;
    level?: Grade;
    category?: SubjectsCatergoryEnum;
    classroom?: UUID;
};
export declare type CreateSubscription = {
    name?: string;
    description?: string;
    cost?: number;
    recurrence_unit?: RecurrenceUnit;
    frequency?: number;
};
export declare type CreateTopicConsumable = {
    name?: string;
    description?: string;
    subject?: UUID;
};
export declare type CreateUser = {
    username?: string;
    password?: string;
    phoneNumber?: string;
    birthdate?: string;
    firstName?: string;
    lastName?: string;
    roles?: UserRoles[];
};
export declare type CreateUserSub = {
    name?: string;
    description?: string;
    subscription?: UUID;
    classroom?: UUID;
    date_billing_start?: string;
};
export declare type DeletePayload = {
    id?: UUID;
};
export declare type Document = {
    id?: string;
    file?: File;
};
export declare type Exercise = {
    id?: string;
    name?: string;
    description?: string;
    questions?: ExerciseQuestion[];
};
export declare type ExerciseAnswer = {
    id?: string;
    answer?: string;
    correct_answer?: boolean;
};
export declare type ExerciseAnswerResponse = {
    id?: string;
    student?: Student;
    marked?: boolean;
    student_response?: string;
    answer?: ExerciseAnswer;
};
export declare type ExerciseQuestion = {
    id?: string;
    question?: string;
    explanation?: string;
    mark?: number;
    answers?: ExerciseAnswer[];
};
export declare type ExerciseReports = {
    id?: string;
    student?: Student;
    status?: MarkingStatusEnum;
    total_marks?: number;
    percentage?: number;
    totalMarkQuestions?: number;
    responses?: ExerciseAnswerResponse[];
};
export declare type ExerciseStatus = {
    id?: string;
    completeStatus?: CompleteStatus;
    started_at?: string;
    completed_at?: string;
};
export declare type File = {
    id?: string;
    name?: string;
    description?: string;
    created_at?: string;
    status?: FileCompleteEnum;
    path?: string;
};
export declare type FileCompleteEnum = "INCOMPLETE" | "COMPLETE";
export declare type Grade = "GRADE_ONE" | "GRADE_TWO" | "GRADE_THREE" | "GRADE_FOUR" | "GRADE_FIVE" | "GRADE_SIX" | "GRADE_SEVEN" | "FORM_ONE" | "FORM_TWO" | "FORM_THREE" | "FORM_FOUR" | "FORM_FIVE" | "FORM_SIX";
export declare type Lesson = {
    id?: string;
    name?: string;
    description?: string;
    topic?: Topic;
};
export declare type LoginUser = {
    username?: string;
    password?: string;
};
export declare type MarkAssessment = {
    report?: UUID;
};
export declare type MarkExercise = {
    report?: UUID;
};
export declare type MarkLongAssessmentAnswer = {
    report?: UUID;
    response?: UUID;
    mark?: number;
};
export declare type MarkingStatusEnum = "COMPLETE" | "MARKING" | "STARTED";
export declare type Media = {
    id?: string;
    file?: File;
    media_type?: PlaylistMediaEnum;
};
export declare type Notes = {
    id?: string;
    name?: string;
    description?: string;
    content?: string;
};
export declare type PlanCost = {
    id?: string;
    plan?: SubscriptionPlan;
    recurrence_period?: number;
    recurrence_unit?: RecurrenceUnit;
    cost?: number;
};
export declare type PlanEnum = "free" | "premium";
export declare type PlanTag = {
    id?: string;
    tag?: string;
};
export declare type Playlist = {
    id?: string;
    name?: string;
    lesson?: Lesson;
    type?: PlaylistMediaEnum;
};
export declare type PlaylistMediaEnum = "video" | "audio";
export declare type RecurrenceUnit = "MONTH" | "YEAR";
export declare type Role = {
    id?: string;
    runhareUser?: RunhareUser;
    role?: string;
};
export declare type RunhareUser = {
    id?: string;
    username: string;
    birthdate?: string;
    email?: string;
    phoneNumber?: string;
    firstName?: string;
    lastName?: string;
    roles?: Role[];
};
export declare type StatsData = {
    users?: number;
};
export declare type Student = {
    id?: string;
    username?: string;
    level?: Grade;
};
export declare type StudentData = {
    level?: Grade;
};
export declare type Subject = {
    id?: string;
    name?: SubjectsEnum;
    description?: string;
    plan?: PlanEnum;
    level?: Grade;
    classroom?: Classroom;
    topics?: Topic[];
    category?: SubjectsCatergoryEnum;
    teacher?: Teacher;
};
export declare type SubjectsCatergoryEnum = "Arts" | "Sciences" | "Commercials";
export declare type SubjectsEnum = "Mathematics" | "Business_Studies" | "Combined_Science" | "Physics" | "Chemistry" | "Computer_Science" | "English" | "Geography" | "Accounting" | "Economics" | "Biology" | "Commerce";
export declare type SubscriptionPlan = {
    id?: string;
    name?: string;
    description?: string;
    tags?: PlanTag[];
    grace_period?: number;
};
export declare type Task = {
    id?: string;
    created_at?: string;
};
export declare type Teacher = {
    id?: string;
    username?: string;
    classrooms?: Classroom[];
    subjects?: Subject[];
};
export declare type TokenResponse = {
    token?: string;
};
export declare type Topic = {
    id?: string;
    name?: string;
    description?: string;
    subject?: Subject;
};
export declare type URL = {
    protocol?: string;
    host?: string;
    port?: number;
    file?: string;
    authority?: string;
    ref?: string;
    hashCode?: number;
    defaultPort?: number;
    content?: {};
    serializedHashCode?: number;
};
export declare type UUID = string;
export declare type UserRoles = "admin" | "teacher" | "student";
export declare type UserSubscription = {
    id?: string;
    user?: RunhareUser;
    subscription?: PlanCost;
    date_billing_start?: string;
    date_billing_end?: string;
    date_billing_last?: string;
    date_billing_next?: string;
    active?: boolean;
    cancelled?: boolean;
};
export declare type AxiosConfig = {
    paramsSerializer?: AxiosRequestConfig["paramsSerializer"];
};
export declare type Config = {
    mutations?: MutationConfigs;
    axios?: AxiosConfig;
};
export declare function initialize(axios: AxiosInstance, config?: Config): {
    requests: {
        readonly assessmentDelete: (payload: DeletePayload) => Promise<unknown>;
        readonly assessmentCreate: (payload: CreateAssessmentConsumable) => Promise<Assessment>;
        readonly assessmentAnswerCreate: (payload: CreateAssessmentAnswer) => Promise<AssessmentAnswer>;
        readonly assessmentAnswerDelete: (id: string) => Promise<{}>;
        readonly assessmentAnswerUpdate: (payload: CreateAssessmentAnswer, id: string) => Promise<AssessmentAnswer>;
        readonly assessmentAnswerList: (q: string) => Promise<AssessmentAnswer[]>;
        readonly assessmentComplete: (payload: CreateAssessmentStatus) => Promise<AssessmentStatus>;
        readonly assessmentQuestionCreate: (payload: CreateAssessmentQuestion) => Promise<AssessmentQuestion>;
        readonly assessmentQuestionList: (assessment_id: string) => Promise<AssessmentQuestion[]>;
        readonly assessmentQuestionDelete: (id: string) => Promise<{}>;
        readonly assessmentQuestionUpdate: (payload: CreateAssessmentQuestion, id: string) => Promise<AssessmentQuestion>;
        readonly assessmentList: (subject_id: string) => Promise<Assessment[]>;
        readonly assessmentStart: (payload: CreateAssessmentStatus) => Promise<AssessmentStatus>;
        readonly assessmentGet: (id: string) => Promise<Assessment>;
        readonly assessmentUpdate: (payload: CreateAssessmentConsumable, id: string) => Promise<Assessment>;
        readonly authenticationLogin: (payload: LoginUser) => Promise<TokenResponse>;
        readonly authenticationRegister: (payload: CreateUser) => Promise<TokenResponse>;
        readonly classroomDelete: (payload: DeletePayload) => Promise<{}>;
        readonly classroomCreate: (payload: CreateClassroomConsumable) => Promise<Classroom>;
        readonly classroomGetByStudentLevel: () => Promise<Classroom[]>;
        readonly classroomGetTeacherId: () => Promise<Classroom[]>;
        readonly classroomGet: (id: string) => Promise<Classroom>;
        readonly classroomUpdate: (payload: CreateClassroomConsumable, id: string) => Promise<Classroom>;
        readonly documentCreate: (payload: CreateDocument) => Promise<Document>;
        readonly documentGetByLesson: (id: string) => Promise<Document[]>;
        readonly documentGet: (id: string) => Promise<Document>;
        readonly exerciseDelete: (payload: DeletePayload) => Promise<unknown>;
        readonly exerciseCreate: (payload: CreateExerciseConsumable) => Promise<Exercise>;
        readonly exerciseAnswerCreate: (payload: CreateExerciseAnswer) => Promise<ExerciseAnswer>;
        readonly exerciseAnswerDelete: (id: string) => Promise<{}>;
        readonly exerciseAnswerUpdate: (payload: CreateExerciseAnswer, id: string) => Promise<ExerciseAnswer>;
        readonly exerciseAnswerList: (q: string) => Promise<ExerciseAnswer[]>;
        readonly exerciseComplete: (payload: CreateExerciseStatus) => Promise<ExerciseStatus>;
        readonly exerciseList: (lesson_id: string) => Promise<Exercise[]>;
        readonly exerciseQuestionCreate: (payload: CreateExerciseQuestion) => Promise<ExerciseQuestion>;
        readonly exerciseQuestionList: (exercise_id: string) => Promise<ExerciseQuestion[]>;
        readonly exerciseQuestionDelete: (id: string) => Promise<{}>;
        readonly exerciseQuestionUpdate: (payload: CreateExerciseQuestion, id: string) => Promise<ExerciseQuestion>;
        readonly exerciseStart: (payload: CreateExerciseStatus) => Promise<ExerciseStatus>;
        readonly exerciseGet: (id: string) => Promise<Exercise>;
        readonly exerciseUpdate: (payload: CreateExerciseConsumable, id: string) => Promise<Exercise>;
        readonly filesList: () => Promise<File[]>;
        readonly filesCreate: (payload: CreateFileConsumable) => Promise<CreateFileResponse>;
        readonly filesComplete: (id: string) => Promise<File>;
        readonly filesGet: (id: string) => Promise<File>;
        readonly assessmentAnswerResponseCreate: (payload: CreateAssessmentAnswerResponse) => Promise<AssessmentAnswerResponse>;
        readonly assessmentAnswerResponseCreateLong: (payload: CreateAssessmentLongAnswerResponse) => Promise<AssessmentAnswerResponse>;
        readonly assessmentAnswerResponseGetResponseByAnswer: (assessment_answer: string) => Promise<AssessmentAnswerResponse>;
        readonly exerciseAnswerResponseCreate: (payload: CreateExerciseAnswerResponse) => Promise<ExerciseAnswerResponse>;
        readonly assessmentGradingCreate: (payload: CreateAssessmentGrading) => Promise<AssessmentReports>;
        readonly assessmentGradingGetByAssessment: (assessment_id: string) => Promise<AssessmentReports[]>;
        readonly assessmentGradingCompleteMarking: (report_id: string) => Promise<AssessmentReports>;
        readonly assessmentGradingMark: (payload: MarkAssessment) => Promise<AssessmentReports>;
        readonly assessmentGradingMarkLong: (payload: MarkLongAssessmentAnswer) => Promise<AssessmentReports>;
        readonly assessmentGradingGet: (id: string) => Promise<AssessmentReports[]>;
        readonly exerciseGradingCreate: (payload: CreateExerciseGrading) => Promise<ExerciseReports>;
        readonly exerciseGradingGetByExercise: (exercise_id: string) => Promise<ExerciseReports[]>;
        readonly exerciseGradingMark: (payload: MarkExercise) => Promise<ExerciseReports>;
        readonly exerciseGradingGet: (id: string) => Promise<ExerciseReports>;
        readonly lessonsDelete: (payload: DeletePayload) => Promise<unknown>;
        readonly lessonsCreate: (payload: CreateLessonConsumable) => Promise<Lesson>;
        readonly lessonsGetLessonsByTopic: (topic_id: string) => Promise<Lesson[]>;
        readonly lessonsGet: (id: string) => Promise<Lesson>;
        readonly lessonsUpdate: (payload: CreateLessonConsumable, id: string) => Promise<Lesson>;
        readonly mediaDelete: (payload: DeletePayload) => Promise<unknown>;
        readonly mediaCreate: (payload: CreateMedia) => Promise<Media>;
        readonly mediaGetByPlaylist: (playlist_id: string) => Promise<Media[]>;
        readonly mediaGet: (id: string) => Promise<Media>;
        readonly mediaUpdate: (payload: CreateMedia, id: string) => Promise<Media>;
        readonly notesDelete: (payload: DeletePayload) => Promise<unknown>;
        readonly notesCreate: (payload: CreateNotesConsumable) => Promise<Notes>;
        readonly notesGetNotesByLesson: (lesson_id: string) => Promise<Notes[]>;
        readonly notesGet: (id: string) => Promise<Notes>;
        readonly notesUpdate: (payload: CreateNotesConsumable, id: string) => Promise<Notes>;
        readonly playlistDelete: (payload: DeletePayload) => Promise<unknown>;
        readonly playlistCreate: (payload: CreatePlaylistConsumable) => Promise<Playlist>;
        readonly playlistGetPlaylistsByLesson: (lesson_id: string) => Promise<Playlist[]>;
        readonly playlistGet: (id: string) => Promise<Playlist>;
        readonly playlistUpdate: (payload: CreatePlaylistConsumable, id: string) => Promise<Playlist>;
        readonly statsGetStats: () => Promise<StatsData>;
        readonly subjectsDelete: (payload: DeletePayload) => Promise<unknown>;
        readonly subjectsCreateClassroomSubject: (payload: CreateSubjects) => Promise<Subject>;
        readonly subjectsListByClassroom: (classroom_id: string) => Promise<Subject[]>;
        readonly subjectsGetByStudentLevel: () => Promise<Subject[]>;
        readonly subjectsCreateSubject: (payload: CreateSubjects) => Promise<Subject>;
        readonly subjectsGet: (id: string) => Promise<Subject>;
        readonly subjectsGetByTeacher: () => Promise<Subject[]>;
        readonly subjectsUpdate: (payload: CreateSubjects, id: string) => Promise<Subject>;
        readonly subscriptionResourceCreate: (payload: CreateSubscription) => Promise<PlanCost>;
        readonly subscriptionResourceUserSub: (payload: CreateUserSub) => Promise<ClassroomSubscription>;
        readonly taskResourceListAll: () => Promise<Task[]>;
        readonly topicsDelete: (payload: DeletePayload) => Promise<unknown>;
        readonly topicsCreate: (payload: CreateTopicConsumable) => Promise<Topic>;
        readonly topicsGetTopicsBySubject: (subject_id: string) => Promise<Topic[]>;
        readonly topicsGet: (id: string) => Promise<Topic>;
        readonly topicsUpdate: (payload: CreateTopicConsumable, id: string) => Promise<Topic>;
        readonly userF: () => Promise<unknown>;
        readonly userGetStudent: () => Promise<Student>;
        readonly userCreateStudent: (payload: StudentData) => Promise<Student>;
        readonly userGetTeacher: () => Promise<Teacher>;
        readonly userCreateTeacher: () => Promise<Teacher>;
        readonly utilsGetCategory: () => Promise<SubjectsCatergoryEnum[]>;
        readonly utilsGetGrades: () => Promise<Grade[]>;
        readonly utilsGetPlan: () => Promise<PlanEnum[]>;
        readonly utilsGetPlaylist: () => Promise<PlaylistMediaEnum[]>;
        readonly utilsGetSubjects: () => Promise<SubjectsEnum[]>;
    };
    queryIds: {
        readonly assessmentAnswerList: (q: string) => readonly ["assessmentAnswerList", string];
        readonly assessmentQuestionList: (assessment_id: string) => readonly ["assessmentQuestionList", string];
        readonly assessmentList: (subject_id: string) => readonly ["assessmentList", string];
        readonly assessmentGet: (id: string) => readonly ["assessmentGet", string];
        readonly classroomGetByStudentLevel: () => readonly ["classroomGetByStudentLevel"];
        readonly classroomGetTeacherId: () => readonly ["classroomGetTeacherId"];
        readonly classroomGet: (id: string) => readonly ["classroomGet", string];
        readonly documentGetByLesson: (id: string) => readonly ["documentGetByLesson", string];
        readonly documentGet: (id: string) => readonly ["documentGet", string];
        readonly exerciseAnswerList: (q: string) => readonly ["exerciseAnswerList", string];
        readonly exerciseList: (lesson_id: string) => readonly ["exerciseList", string];
        readonly exerciseQuestionList: (exercise_id: string) => readonly ["exerciseQuestionList", string];
        readonly exerciseGet: (id: string) => readonly ["exerciseGet", string];
        readonly filesList: () => readonly ["filesList"];
        readonly filesGet: (id: string) => readonly ["filesGet", string];
        readonly assessmentAnswerResponseGetResponseByAnswer: (assessment_answer: string) => readonly ["assessmentAnswerResponseGetResponseByAnswer", string];
        readonly assessmentGradingGetByAssessment: (assessment_id: string) => readonly ["assessmentGradingGetByAssessment", string];
        readonly assessmentGradingGet: (id: string) => readonly ["assessmentGradingGet", string];
        readonly exerciseGradingGetByExercise: (exercise_id: string) => readonly ["exerciseGradingGetByExercise", string];
        readonly exerciseGradingGet: (id: string) => readonly ["exerciseGradingGet", string];
        readonly lessonsGetLessonsByTopic: (topic_id: string) => readonly ["lessonsGetLessonsByTopic", string];
        readonly lessonsGet: (id: string) => readonly ["lessonsGet", string];
        readonly mediaGetByPlaylist: (playlist_id: string) => readonly ["mediaGetByPlaylist", string];
        readonly mediaGet: (id: string) => readonly ["mediaGet", string];
        readonly notesGetNotesByLesson: (lesson_id: string) => readonly ["notesGetNotesByLesson", string];
        readonly notesGet: (id: string) => readonly ["notesGet", string];
        readonly playlistGetPlaylistsByLesson: (lesson_id: string) => readonly ["playlistGetPlaylistsByLesson", string];
        readonly playlistGet: (id: string) => readonly ["playlistGet", string];
        readonly statsGetStats: () => readonly ["statsGetStats"];
        readonly subjectsListByClassroom: (classroom_id: string) => readonly ["subjectsListByClassroom", string];
        readonly subjectsGetByStudentLevel: () => readonly ["subjectsGetByStudentLevel"];
        readonly subjectsGet: (id: string) => readonly ["subjectsGet", string];
        readonly subjectsGetByTeacher: () => readonly ["subjectsGetByTeacher"];
        readonly taskResourceListAll: () => readonly ["taskResourceListAll"];
        readonly topicsGetTopicsBySubject: (subject_id: string) => readonly ["topicsGetTopicsBySubject", string];
        readonly topicsGet: (id: string) => readonly ["topicsGet", string];
        readonly userGetStudent: () => readonly ["userGetStudent"];
        readonly userGetTeacher: () => readonly ["userGetTeacher"];
        readonly utilsGetCategory: () => readonly ["utilsGetCategory"];
        readonly utilsGetGrades: () => readonly ["utilsGetGrades"];
        readonly utilsGetPlan: () => readonly ["utilsGetPlan"];
        readonly utilsGetPlaylist: () => readonly ["utilsGetPlaylist"];
        readonly utilsGetSubjects: () => readonly ["utilsGetSubjects"];
    };
    queries: {
        readonly useAssessmentAnswerList: (q: string, options?: Omit<UseQueryOptions<AssessmentAnswer[], unknown, AssessmentAnswer[], readonly ["assessmentAnswerList", string]>, "queryKey" | "queryFn">) => UseQueryResult<AssessmentAnswer[], unknown>;
        readonly useAssessmentQuestionList: (assessment_id: string, options?: Omit<UseQueryOptions<AssessmentQuestion[], unknown, AssessmentQuestion[], readonly ["assessmentQuestionList", string]>, "queryKey" | "queryFn">) => UseQueryResult<AssessmentQuestion[], unknown>;
        readonly useAssessmentList: (subject_id: string, options?: Omit<UseQueryOptions<Assessment[], unknown, Assessment[], readonly ["assessmentList", string]>, "queryKey" | "queryFn">) => UseQueryResult<Assessment[], unknown>;
        readonly useAssessmentGet: (id: string, options?: Omit<UseQueryOptions<Assessment, unknown, Assessment, readonly ["assessmentGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Assessment, unknown>;
        readonly useClassroomGetByStudentLevel: (options?: Omit<UseQueryOptions<Classroom[], unknown, Classroom[], readonly ["classroomGetByStudentLevel"]>, "queryKey" | "queryFn">) => UseQueryResult<Classroom[], unknown>;
        readonly useClassroomGetTeacherId: (options?: Omit<UseQueryOptions<Classroom[], unknown, Classroom[], readonly ["classroomGetTeacherId"]>, "queryKey" | "queryFn">) => UseQueryResult<Classroom[], unknown>;
        readonly useClassroomGet: (id: string, options?: Omit<UseQueryOptions<Classroom, unknown, Classroom, readonly ["classroomGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Classroom, unknown>;
        readonly useDocumentGetByLesson: (id: string, options?: Omit<UseQueryOptions<Document[], unknown, Document[], readonly ["documentGetByLesson", string]>, "queryKey" | "queryFn">) => UseQueryResult<Document[], unknown>;
        readonly useDocumentGet: (id: string, options?: Omit<UseQueryOptions<Document, unknown, Document, readonly ["documentGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Document, unknown>;
        readonly useExerciseAnswerList: (q: string, options?: Omit<UseQueryOptions<ExerciseAnswer[], unknown, ExerciseAnswer[], readonly ["exerciseAnswerList", string]>, "queryKey" | "queryFn">) => UseQueryResult<ExerciseAnswer[], unknown>;
        readonly useExerciseList: (lesson_id: string, options?: Omit<UseQueryOptions<Exercise[], unknown, Exercise[], readonly ["exerciseList", string]>, "queryKey" | "queryFn">) => UseQueryResult<Exercise[], unknown>;
        readonly useExerciseQuestionList: (exercise_id: string, options?: Omit<UseQueryOptions<ExerciseQuestion[], unknown, ExerciseQuestion[], readonly ["exerciseQuestionList", string]>, "queryKey" | "queryFn">) => UseQueryResult<ExerciseQuestion[], unknown>;
        readonly useExerciseGet: (id: string, options?: Omit<UseQueryOptions<Exercise, unknown, Exercise, readonly ["exerciseGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Exercise, unknown>;
        readonly useFilesList: (options?: Omit<UseQueryOptions<File[], unknown, File[], readonly ["filesList"]>, "queryKey" | "queryFn">) => UseQueryResult<File[], unknown>;
        readonly useFilesGet: (id: string, options?: Omit<UseQueryOptions<File, unknown, File, readonly ["filesGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<File, unknown>;
        readonly useAssessmentAnswerResponseGetResponseByAnswer: (assessment_answer: string, options?: Omit<UseQueryOptions<AssessmentAnswerResponse, unknown, AssessmentAnswerResponse, readonly ["assessmentAnswerResponseGetResponseByAnswer", string]>, "queryKey" | "queryFn">) => UseQueryResult<AssessmentAnswerResponse, unknown>;
        readonly useAssessmentGradingGetByAssessment: (assessment_id: string, options?: Omit<UseQueryOptions<AssessmentReports[], unknown, AssessmentReports[], readonly ["assessmentGradingGetByAssessment", string]>, "queryKey" | "queryFn">) => UseQueryResult<AssessmentReports[], unknown>;
        readonly useAssessmentGradingGet: (id: string, options?: Omit<UseQueryOptions<AssessmentReports[], unknown, AssessmentReports[], readonly ["assessmentGradingGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<AssessmentReports[], unknown>;
        readonly useExerciseGradingGetByExercise: (exercise_id: string, options?: Omit<UseQueryOptions<ExerciseReports[], unknown, ExerciseReports[], readonly ["exerciseGradingGetByExercise", string]>, "queryKey" | "queryFn">) => UseQueryResult<ExerciseReports[], unknown>;
        readonly useExerciseGradingGet: (id: string, options?: Omit<UseQueryOptions<ExerciseReports, unknown, ExerciseReports, readonly ["exerciseGradingGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<ExerciseReports, unknown>;
        readonly useLessonsGetLessonsByTopic: (topic_id: string, options?: Omit<UseQueryOptions<Lesson[], unknown, Lesson[], readonly ["lessonsGetLessonsByTopic", string]>, "queryKey" | "queryFn">) => UseQueryResult<Lesson[], unknown>;
        readonly useLessonsGet: (id: string, options?: Omit<UseQueryOptions<Lesson, unknown, Lesson, readonly ["lessonsGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Lesson, unknown>;
        readonly useMediaGetByPlaylist: (playlist_id: string, options?: Omit<UseQueryOptions<Media[], unknown, Media[], readonly ["mediaGetByPlaylist", string]>, "queryKey" | "queryFn">) => UseQueryResult<Media[], unknown>;
        readonly useMediaGet: (id: string, options?: Omit<UseQueryOptions<Media, unknown, Media, readonly ["mediaGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Media, unknown>;
        readonly useNotesGetNotesByLesson: (lesson_id: string, options?: Omit<UseQueryOptions<Notes[], unknown, Notes[], readonly ["notesGetNotesByLesson", string]>, "queryKey" | "queryFn">) => UseQueryResult<Notes[], unknown>;
        readonly useNotesGet: (id: string, options?: Omit<UseQueryOptions<Notes, unknown, Notes, readonly ["notesGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Notes, unknown>;
        readonly usePlaylistGetPlaylistsByLesson: (lesson_id: string, options?: Omit<UseQueryOptions<Playlist[], unknown, Playlist[], readonly ["playlistGetPlaylistsByLesson", string]>, "queryKey" | "queryFn">) => UseQueryResult<Playlist[], unknown>;
        readonly usePlaylistGet: (id: string, options?: Omit<UseQueryOptions<Playlist, unknown, Playlist, readonly ["playlistGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Playlist, unknown>;
        readonly useStatsGetStats: (options?: Omit<UseQueryOptions<StatsData, unknown, StatsData, readonly ["statsGetStats"]>, "queryKey" | "queryFn">) => UseQueryResult<StatsData, unknown>;
        readonly useSubjectsListByClassroom: (classroom_id: string, options?: Omit<UseQueryOptions<Subject[], unknown, Subject[], readonly ["subjectsListByClassroom", string]>, "queryKey" | "queryFn">) => UseQueryResult<Subject[], unknown>;
        readonly useSubjectsGetByStudentLevel: (options?: Omit<UseQueryOptions<Subject[], unknown, Subject[], readonly ["subjectsGetByStudentLevel"]>, "queryKey" | "queryFn">) => UseQueryResult<Subject[], unknown>;
        readonly useSubjectsGet: (id: string, options?: Omit<UseQueryOptions<Subject, unknown, Subject, readonly ["subjectsGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Subject, unknown>;
        readonly useSubjectsGetByTeacher: (options?: Omit<UseQueryOptions<Subject[], unknown, Subject[], readonly ["subjectsGetByTeacher"]>, "queryKey" | "queryFn">) => UseQueryResult<Subject[], unknown>;
        readonly useTaskResourceListAll: (options?: Omit<UseQueryOptions<Task[], unknown, Task[], readonly ["taskResourceListAll"]>, "queryKey" | "queryFn">) => UseQueryResult<Task[], unknown>;
        readonly useTopicsGetTopicsBySubject: (subject_id: string, options?: Omit<UseQueryOptions<Topic[], unknown, Topic[], readonly ["topicsGetTopicsBySubject", string]>, "queryKey" | "queryFn">) => UseQueryResult<Topic[], unknown>;
        readonly useTopicsGet: (id: string, options?: Omit<UseQueryOptions<Topic, unknown, Topic, readonly ["topicsGet", string]>, "queryKey" | "queryFn">) => UseQueryResult<Topic, unknown>;
        readonly useUserGetStudent: (options?: Omit<UseQueryOptions<Student, unknown, Student, readonly ["userGetStudent"]>, "queryKey" | "queryFn">) => UseQueryResult<Student, unknown>;
        readonly useUserGetTeacher: (options?: Omit<UseQueryOptions<Teacher, unknown, Teacher, readonly ["userGetTeacher"]>, "queryKey" | "queryFn">) => UseQueryResult<Teacher, unknown>;
        readonly useUtilsGetCategory: (options?: Omit<UseQueryOptions<SubjectsCatergoryEnum[], unknown, SubjectsCatergoryEnum[], readonly ["utilsGetCategory"]>, "queryKey" | "queryFn">) => UseQueryResult<SubjectsCatergoryEnum[], unknown>;
        readonly useUtilsGetGrades: (options?: Omit<UseQueryOptions<Grade[], unknown, Grade[], readonly ["utilsGetGrades"]>, "queryKey" | "queryFn">) => UseQueryResult<Grade[], unknown>;
        readonly useUtilsGetPlan: (options?: Omit<UseQueryOptions<PlanEnum[], unknown, PlanEnum[], readonly ["utilsGetPlan"]>, "queryKey" | "queryFn">) => UseQueryResult<PlanEnum[], unknown>;
        readonly useUtilsGetPlaylist: (options?: Omit<UseQueryOptions<PlaylistMediaEnum[], unknown, PlaylistMediaEnum[], readonly ["utilsGetPlaylist"]>, "queryKey" | "queryFn">) => UseQueryResult<PlaylistMediaEnum[], unknown>;
        readonly useUtilsGetSubjects: (options?: Omit<UseQueryOptions<SubjectsEnum[], unknown, SubjectsEnum[], readonly ["utilsGetSubjects"]>, "queryKey" | "queryFn">) => UseQueryResult<SubjectsEnum[], unknown>;
    };
    mutations: {
        readonly useAssessmentCreate: (options?: Omit<UseMutationOptions<Assessment, unknown, CreateAssessmentConsumable, unknown>, "mutationFn">) => UseMutationResult<Assessment, unknown, CreateAssessmentConsumable, unknown>;
        readonly useAssessmentDelete: (options?: Omit<UseMutationOptions<unknown, unknown, DeletePayload, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, DeletePayload, unknown>;
        readonly useAssessmentAnswerCreate: (options?: Omit<UseMutationOptions<AssessmentAnswer, unknown, CreateAssessmentAnswer, unknown>, "mutationFn">) => UseMutationResult<AssessmentAnswer, unknown, CreateAssessmentAnswer, unknown>;
        readonly useAssessmentAnswerUpdate: (id: string, options?: Omit<UseMutationOptions<AssessmentAnswer, unknown, CreateAssessmentAnswer, unknown>, "mutationFn">) => UseMutationResult<AssessmentAnswer, unknown, CreateAssessmentAnswer, unknown>;
        readonly useAssessmentAnswerDelete: (id: string, options?: Omit<UseMutationOptions<{}, unknown, unknown, unknown>, "mutationFn">) => UseMutationResult<{}, unknown, unknown, unknown>;
        readonly useAssessmentComplete: (options?: Omit<UseMutationOptions<AssessmentStatus, unknown, CreateAssessmentStatus, unknown>, "mutationFn">) => UseMutationResult<AssessmentStatus, unknown, CreateAssessmentStatus, unknown>;
        readonly useAssessmentQuestionCreate: (options?: Omit<UseMutationOptions<AssessmentQuestion, unknown, CreateAssessmentQuestion, unknown>, "mutationFn">) => UseMutationResult<AssessmentQuestion, unknown, CreateAssessmentQuestion, unknown>;
        readonly useAssessmentQuestionUpdate: (id: string, options?: Omit<UseMutationOptions<AssessmentQuestion, unknown, CreateAssessmentQuestion, unknown>, "mutationFn">) => UseMutationResult<AssessmentQuestion, unknown, CreateAssessmentQuestion, unknown>;
        readonly useAssessmentQuestionDelete: (id: string, options?: Omit<UseMutationOptions<{}, unknown, unknown, unknown>, "mutationFn">) => UseMutationResult<{}, unknown, unknown, unknown>;
        readonly useAssessmentStart: (options?: Omit<UseMutationOptions<AssessmentStatus, unknown, CreateAssessmentStatus, unknown>, "mutationFn">) => UseMutationResult<AssessmentStatus, unknown, CreateAssessmentStatus, unknown>;
        readonly useAssessmentUpdate: (id: string, options?: Omit<UseMutationOptions<Assessment, unknown, CreateAssessmentConsumable, unknown>, "mutationFn">) => UseMutationResult<Assessment, unknown, CreateAssessmentConsumable, unknown>;
        readonly useAuthenticationLogin: (options?: Omit<UseMutationOptions<TokenResponse, unknown, LoginUser, unknown>, "mutationFn">) => UseMutationResult<TokenResponse, unknown, LoginUser, unknown>;
        readonly useAuthenticationRegister: (options?: Omit<UseMutationOptions<TokenResponse, unknown, CreateUser, unknown>, "mutationFn">) => UseMutationResult<TokenResponse, unknown, CreateUser, unknown>;
        readonly useClassroomCreate: (options?: Omit<UseMutationOptions<Classroom, unknown, CreateClassroomConsumable, unknown>, "mutationFn">) => UseMutationResult<Classroom, unknown, CreateClassroomConsumable, unknown>;
        readonly useClassroomDelete: (options?: Omit<UseMutationOptions<{}, unknown, DeletePayload, unknown>, "mutationFn">) => UseMutationResult<{}, unknown, DeletePayload, unknown>;
        readonly useClassroomUpdate: (id: string, options?: Omit<UseMutationOptions<Classroom, unknown, CreateClassroomConsumable, unknown>, "mutationFn">) => UseMutationResult<Classroom, unknown, CreateClassroomConsumable, unknown>;
        readonly useDocumentCreate: (options?: Omit<UseMutationOptions<Document, unknown, CreateDocument, unknown>, "mutationFn">) => UseMutationResult<Document, unknown, CreateDocument, unknown>;
        readonly useExerciseCreate: (options?: Omit<UseMutationOptions<Exercise, unknown, CreateExerciseConsumable, unknown>, "mutationFn">) => UseMutationResult<Exercise, unknown, CreateExerciseConsumable, unknown>;
        readonly useExerciseDelete: (options?: Omit<UseMutationOptions<unknown, unknown, DeletePayload, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, DeletePayload, unknown>;
        readonly useExerciseAnswerCreate: (options?: Omit<UseMutationOptions<ExerciseAnswer, unknown, CreateExerciseAnswer, unknown>, "mutationFn">) => UseMutationResult<ExerciseAnswer, unknown, CreateExerciseAnswer, unknown>;
        readonly useExerciseAnswerUpdate: (id: string, options?: Omit<UseMutationOptions<ExerciseAnswer, unknown, CreateExerciseAnswer, unknown>, "mutationFn">) => UseMutationResult<ExerciseAnswer, unknown, CreateExerciseAnswer, unknown>;
        readonly useExerciseAnswerDelete: (id: string, options?: Omit<UseMutationOptions<{}, unknown, unknown, unknown>, "mutationFn">) => UseMutationResult<{}, unknown, unknown, unknown>;
        readonly useExerciseComplete: (options?: Omit<UseMutationOptions<ExerciseStatus, unknown, CreateExerciseStatus, unknown>, "mutationFn">) => UseMutationResult<ExerciseStatus, unknown, CreateExerciseStatus, unknown>;
        readonly useExerciseQuestionCreate: (options?: Omit<UseMutationOptions<ExerciseQuestion, unknown, CreateExerciseQuestion, unknown>, "mutationFn">) => UseMutationResult<ExerciseQuestion, unknown, CreateExerciseQuestion, unknown>;
        readonly useExerciseQuestionUpdate: (id: string, options?: Omit<UseMutationOptions<ExerciseQuestion, unknown, CreateExerciseQuestion, unknown>, "mutationFn">) => UseMutationResult<ExerciseQuestion, unknown, CreateExerciseQuestion, unknown>;
        readonly useExerciseQuestionDelete: (id: string, options?: Omit<UseMutationOptions<{}, unknown, unknown, unknown>, "mutationFn">) => UseMutationResult<{}, unknown, unknown, unknown>;
        readonly useExerciseStart: (options?: Omit<UseMutationOptions<ExerciseStatus, unknown, CreateExerciseStatus, unknown>, "mutationFn">) => UseMutationResult<ExerciseStatus, unknown, CreateExerciseStatus, unknown>;
        readonly useExerciseUpdate: (id: string, options?: Omit<UseMutationOptions<Exercise, unknown, CreateExerciseConsumable, unknown>, "mutationFn">) => UseMutationResult<Exercise, unknown, CreateExerciseConsumable, unknown>;
        readonly useFilesCreate: (options?: Omit<UseMutationOptions<CreateFileResponse, unknown, CreateFileConsumable, unknown>, "mutationFn">) => UseMutationResult<CreateFileResponse, unknown, CreateFileConsumable, unknown>;
        readonly useFilesComplete: (id: string, options?: Omit<UseMutationOptions<File, unknown, unknown, unknown>, "mutationFn">) => UseMutationResult<File, unknown, unknown, unknown>;
        readonly useAssessmentAnswerResponseCreate: (options?: Omit<UseMutationOptions<AssessmentAnswerResponse, unknown, CreateAssessmentAnswerResponse, unknown>, "mutationFn">) => UseMutationResult<AssessmentAnswerResponse, unknown, CreateAssessmentAnswerResponse, unknown>;
        readonly useAssessmentAnswerResponseCreateLong: (options?: Omit<UseMutationOptions<AssessmentAnswerResponse, unknown, CreateAssessmentLongAnswerResponse, unknown>, "mutationFn">) => UseMutationResult<AssessmentAnswerResponse, unknown, CreateAssessmentLongAnswerResponse, unknown>;
        readonly useExerciseAnswerResponseCreate: (options?: Omit<UseMutationOptions<ExerciseAnswerResponse, unknown, CreateExerciseAnswerResponse, unknown>, "mutationFn">) => UseMutationResult<ExerciseAnswerResponse, unknown, CreateExerciseAnswerResponse, unknown>;
        readonly useAssessmentGradingCreate: (options?: Omit<UseMutationOptions<AssessmentReports, unknown, CreateAssessmentGrading, unknown>, "mutationFn">) => UseMutationResult<AssessmentReports, unknown, CreateAssessmentGrading, unknown>;
        readonly useAssessmentGradingCompleteMarking: (report_id: string, options?: Omit<UseMutationOptions<AssessmentReports, unknown, unknown, unknown>, "mutationFn">) => UseMutationResult<AssessmentReports, unknown, unknown, unknown>;
        readonly useAssessmentGradingMark: (options?: Omit<UseMutationOptions<AssessmentReports, unknown, MarkAssessment, unknown>, "mutationFn">) => UseMutationResult<AssessmentReports, unknown, MarkAssessment, unknown>;
        readonly useAssessmentGradingMarkLong: (options?: Omit<UseMutationOptions<AssessmentReports, unknown, MarkLongAssessmentAnswer, unknown>, "mutationFn">) => UseMutationResult<AssessmentReports, unknown, MarkLongAssessmentAnswer, unknown>;
        readonly useExerciseGradingCreate: (options?: Omit<UseMutationOptions<ExerciseReports, unknown, CreateExerciseGrading, unknown>, "mutationFn">) => UseMutationResult<ExerciseReports, unknown, CreateExerciseGrading, unknown>;
        readonly useExerciseGradingMark: (options?: Omit<UseMutationOptions<ExerciseReports, unknown, MarkExercise, unknown>, "mutationFn">) => UseMutationResult<ExerciseReports, unknown, MarkExercise, unknown>;
        readonly useLessonsCreate: (options?: Omit<UseMutationOptions<Lesson, unknown, CreateLessonConsumable, unknown>, "mutationFn">) => UseMutationResult<Lesson, unknown, CreateLessonConsumable, unknown>;
        readonly useLessonsDelete: (options?: Omit<UseMutationOptions<unknown, unknown, DeletePayload, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, DeletePayload, unknown>;
        readonly useLessonsUpdate: (id: string, options?: Omit<UseMutationOptions<Lesson, unknown, CreateLessonConsumable, unknown>, "mutationFn">) => UseMutationResult<Lesson, unknown, CreateLessonConsumable, unknown>;
        readonly useMediaCreate: (options?: Omit<UseMutationOptions<Media, unknown, CreateMedia, unknown>, "mutationFn">) => UseMutationResult<Media, unknown, CreateMedia, unknown>;
        readonly useMediaDelete: (options?: Omit<UseMutationOptions<unknown, unknown, DeletePayload, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, DeletePayload, unknown>;
        readonly useMediaUpdate: (id: string, options?: Omit<UseMutationOptions<Media, unknown, CreateMedia, unknown>, "mutationFn">) => UseMutationResult<Media, unknown, CreateMedia, unknown>;
        readonly useNotesCreate: (options?: Omit<UseMutationOptions<Notes, unknown, CreateNotesConsumable, unknown>, "mutationFn">) => UseMutationResult<Notes, unknown, CreateNotesConsumable, unknown>;
        readonly useNotesDelete: (options?: Omit<UseMutationOptions<unknown, unknown, DeletePayload, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, DeletePayload, unknown>;
        readonly useNotesUpdate: (id: string, options?: Omit<UseMutationOptions<Notes, unknown, CreateNotesConsumable, unknown>, "mutationFn">) => UseMutationResult<Notes, unknown, CreateNotesConsumable, unknown>;
        readonly usePlaylistCreate: (options?: Omit<UseMutationOptions<Playlist, unknown, CreatePlaylistConsumable, unknown>, "mutationFn">) => UseMutationResult<Playlist, unknown, CreatePlaylistConsumable, unknown>;
        readonly usePlaylistDelete: (options?: Omit<UseMutationOptions<unknown, unknown, DeletePayload, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, DeletePayload, unknown>;
        readonly usePlaylistUpdate: (id: string, options?: Omit<UseMutationOptions<Playlist, unknown, CreatePlaylistConsumable, unknown>, "mutationFn">) => UseMutationResult<Playlist, unknown, CreatePlaylistConsumable, unknown>;
        readonly useSubjectsDelete: (options?: Omit<UseMutationOptions<unknown, unknown, DeletePayload, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, DeletePayload, unknown>;
        readonly useSubjectsCreateClassroomSubject: (options?: Omit<UseMutationOptions<Subject, unknown, CreateSubjects, unknown>, "mutationFn">) => UseMutationResult<Subject, unknown, CreateSubjects, unknown>;
        readonly useSubjectsCreateSubject: (options?: Omit<UseMutationOptions<Subject, unknown, CreateSubjects, unknown>, "mutationFn">) => UseMutationResult<Subject, unknown, CreateSubjects, unknown>;
        readonly useSubjectsUpdate: (id: string, options?: Omit<UseMutationOptions<Subject, unknown, CreateSubjects, unknown>, "mutationFn">) => UseMutationResult<Subject, unknown, CreateSubjects, unknown>;
        readonly useSubscriptionResourceCreate: (options?: Omit<UseMutationOptions<PlanCost, unknown, CreateSubscription, unknown>, "mutationFn">) => UseMutationResult<PlanCost, unknown, CreateSubscription, unknown>;
        readonly useSubscriptionResourceUserSub: (options?: Omit<UseMutationOptions<ClassroomSubscription, unknown, CreateUserSub, unknown>, "mutationFn">) => UseMutationResult<ClassroomSubscription, unknown, CreateUserSub, unknown>;
        readonly useTopicsCreate: (options?: Omit<UseMutationOptions<Topic, unknown, CreateTopicConsumable, unknown>, "mutationFn">) => UseMutationResult<Topic, unknown, CreateTopicConsumable, unknown>;
        readonly useTopicsDelete: (options?: Omit<UseMutationOptions<unknown, unknown, DeletePayload, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, DeletePayload, unknown>;
        readonly useTopicsUpdate: (id: string, options?: Omit<UseMutationOptions<Topic, unknown, CreateTopicConsumable, unknown>, "mutationFn">) => UseMutationResult<Topic, unknown, CreateTopicConsumable, unknown>;
        readonly useUserF: (options?: Omit<UseMutationOptions<unknown, unknown, unknown, unknown>, "mutationFn">) => UseMutationResult<unknown, unknown, unknown, unknown>;
        readonly useUserCreateStudent: (options?: Omit<UseMutationOptions<Student, unknown, StudentData, unknown>, "mutationFn">) => UseMutationResult<Student, unknown, StudentData, unknown>;
        readonly useUserCreateTeacher: (options?: Omit<UseMutationOptions<Teacher, unknown, unknown, unknown>, "mutationFn">) => UseMutationResult<Teacher, unknown, unknown, unknown>;
    };
};
declare function makeRequests(axios: AxiosInstance, config?: AxiosConfig): {
    readonly assessmentDelete: (payload: DeletePayload) => Promise<unknown>;
    readonly assessmentCreate: (payload: CreateAssessmentConsumable) => Promise<Assessment>;
    readonly assessmentAnswerCreate: (payload: CreateAssessmentAnswer) => Promise<AssessmentAnswer>;
    readonly assessmentAnswerDelete: (id: UUID) => Promise<{}>;
    readonly assessmentAnswerUpdate: (payload: CreateAssessmentAnswer, id: UUID) => Promise<AssessmentAnswer>;
    readonly assessmentAnswerList: (q: UUID) => Promise<AssessmentAnswer[]>;
    readonly assessmentComplete: (payload: CreateAssessmentStatus) => Promise<AssessmentStatus>;
    readonly assessmentQuestionCreate: (payload: CreateAssessmentQuestion) => Promise<AssessmentQuestion>;
    readonly assessmentQuestionList: (assessment_id: UUID) => Promise<AssessmentQuestion[]>;
    readonly assessmentQuestionDelete: (id: UUID) => Promise<{}>;
    readonly assessmentQuestionUpdate: (payload: CreateAssessmentQuestion, id: UUID) => Promise<AssessmentQuestion>;
    readonly assessmentList: (subject_id: UUID) => Promise<Assessment[]>;
    readonly assessmentStart: (payload: CreateAssessmentStatus) => Promise<AssessmentStatus>;
    readonly assessmentGet: (id: UUID) => Promise<Assessment>;
    readonly assessmentUpdate: (payload: CreateAssessmentConsumable, id: UUID) => Promise<Assessment>;
    readonly authenticationLogin: (payload: LoginUser) => Promise<TokenResponse>;
    readonly authenticationRegister: (payload: CreateUser) => Promise<TokenResponse>;
    readonly classroomDelete: (payload: DeletePayload) => Promise<{}>;
    readonly classroomCreate: (payload: CreateClassroomConsumable) => Promise<Classroom>;
    readonly classroomGetByStudentLevel: () => Promise<Classroom[]>;
    readonly classroomGetTeacherId: () => Promise<Classroom[]>;
    readonly classroomGet: (id: UUID) => Promise<Classroom>;
    readonly classroomUpdate: (payload: CreateClassroomConsumable, id: UUID) => Promise<Classroom>;
    readonly documentCreate: (payload: CreateDocument) => Promise<Document>;
    readonly documentGetByLesson: (id: UUID) => Promise<Document[]>;
    readonly documentGet: (id: UUID) => Promise<Document>;
    readonly exerciseDelete: (payload: DeletePayload) => Promise<unknown>;
    readonly exerciseCreate: (payload: CreateExerciseConsumable) => Promise<Exercise>;
    readonly exerciseAnswerCreate: (payload: CreateExerciseAnswer) => Promise<ExerciseAnswer>;
    readonly exerciseAnswerDelete: (id: UUID) => Promise<{}>;
    readonly exerciseAnswerUpdate: (payload: CreateExerciseAnswer, id: UUID) => Promise<ExerciseAnswer>;
    readonly exerciseAnswerList: (q: UUID) => Promise<ExerciseAnswer[]>;
    readonly exerciseComplete: (payload: CreateExerciseStatus) => Promise<ExerciseStatus>;
    readonly exerciseList: (lesson_id: UUID) => Promise<Exercise[]>;
    readonly exerciseQuestionCreate: (payload: CreateExerciseQuestion) => Promise<ExerciseQuestion>;
    readonly exerciseQuestionList: (exercise_id: UUID) => Promise<ExerciseQuestion[]>;
    readonly exerciseQuestionDelete: (id: UUID) => Promise<{}>;
    readonly exerciseQuestionUpdate: (payload: CreateExerciseQuestion, id: UUID) => Promise<ExerciseQuestion>;
    readonly exerciseStart: (payload: CreateExerciseStatus) => Promise<ExerciseStatus>;
    readonly exerciseGet: (id: UUID) => Promise<Exercise>;
    readonly exerciseUpdate: (payload: CreateExerciseConsumable, id: UUID) => Promise<Exercise>;
    readonly filesList: () => Promise<File[]>;
    readonly filesCreate: (payload: CreateFileConsumable) => Promise<CreateFileResponse>;
    readonly filesComplete: (id: UUID) => Promise<File>;
    readonly filesGet: (id: UUID) => Promise<File>;
    readonly assessmentAnswerResponseCreate: (payload: CreateAssessmentAnswerResponse) => Promise<AssessmentAnswerResponse>;
    readonly assessmentAnswerResponseCreateLong: (payload: CreateAssessmentLongAnswerResponse) => Promise<AssessmentAnswerResponse>;
    readonly assessmentAnswerResponseGetResponseByAnswer: (assessment_answer: UUID) => Promise<AssessmentAnswerResponse>;
    readonly exerciseAnswerResponseCreate: (payload: CreateExerciseAnswerResponse) => Promise<ExerciseAnswerResponse>;
    readonly assessmentGradingCreate: (payload: CreateAssessmentGrading) => Promise<AssessmentReports>;
    readonly assessmentGradingGetByAssessment: (assessment_id: UUID) => Promise<AssessmentReports[]>;
    readonly assessmentGradingCompleteMarking: (report_id: UUID) => Promise<AssessmentReports>;
    readonly assessmentGradingMark: (payload: MarkAssessment) => Promise<AssessmentReports>;
    readonly assessmentGradingMarkLong: (payload: MarkLongAssessmentAnswer) => Promise<AssessmentReports>;
    readonly assessmentGradingGet: (id: UUID) => Promise<AssessmentReports[]>;
    readonly exerciseGradingCreate: (payload: CreateExerciseGrading) => Promise<ExerciseReports>;
    readonly exerciseGradingGetByExercise: (exercise_id: UUID) => Promise<ExerciseReports[]>;
    readonly exerciseGradingMark: (payload: MarkExercise) => Promise<ExerciseReports>;
    readonly exerciseGradingGet: (id: UUID) => Promise<ExerciseReports>;
    readonly lessonsDelete: (payload: DeletePayload) => Promise<unknown>;
    readonly lessonsCreate: (payload: CreateLessonConsumable) => Promise<Lesson>;
    readonly lessonsGetLessonsByTopic: (topic_id: UUID) => Promise<Lesson[]>;
    readonly lessonsGet: (id: UUID) => Promise<Lesson>;
    readonly lessonsUpdate: (payload: CreateLessonConsumable, id: UUID) => Promise<Lesson>;
    readonly mediaDelete: (payload: DeletePayload) => Promise<unknown>;
    readonly mediaCreate: (payload: CreateMedia) => Promise<Media>;
    readonly mediaGetByPlaylist: (playlist_id: UUID) => Promise<Media[]>;
    readonly mediaGet: (id: UUID) => Promise<Media>;
    readonly mediaUpdate: (payload: CreateMedia, id: UUID) => Promise<Media>;
    readonly notesDelete: (payload: DeletePayload) => Promise<unknown>;
    readonly notesCreate: (payload: CreateNotesConsumable) => Promise<Notes>;
    readonly notesGetNotesByLesson: (lesson_id: UUID) => Promise<Notes[]>;
    readonly notesGet: (id: UUID) => Promise<Notes>;
    readonly notesUpdate: (payload: CreateNotesConsumable, id: UUID) => Promise<Notes>;
    readonly playlistDelete: (payload: DeletePayload) => Promise<unknown>;
    readonly playlistCreate: (payload: CreatePlaylistConsumable) => Promise<Playlist>;
    readonly playlistGetPlaylistsByLesson: (lesson_id: UUID) => Promise<Playlist[]>;
    readonly playlistGet: (id: UUID) => Promise<Playlist>;
    readonly playlistUpdate: (payload: CreatePlaylistConsumable, id: UUID) => Promise<Playlist>;
    readonly statsGetStats: () => Promise<StatsData>;
    readonly subjectsDelete: (payload: DeletePayload) => Promise<unknown>;
    readonly subjectsCreateClassroomSubject: (payload: CreateSubjects) => Promise<Subject>;
    readonly subjectsListByClassroom: (classroom_id: UUID) => Promise<Subject[]>;
    readonly subjectsGetByStudentLevel: () => Promise<Subject[]>;
    readonly subjectsCreateSubject: (payload: CreateSubjects) => Promise<Subject>;
    readonly subjectsGet: (id: UUID) => Promise<Subject>;
    readonly subjectsGetByTeacher: () => Promise<Subject[]>;
    readonly subjectsUpdate: (payload: CreateSubjects, id: string) => Promise<Subject>;
    readonly subscriptionResourceCreate: (payload: CreateSubscription) => Promise<PlanCost>;
    readonly subscriptionResourceUserSub: (payload: CreateUserSub) => Promise<ClassroomSubscription>;
    readonly taskResourceListAll: () => Promise<Task[]>;
    readonly topicsDelete: (payload: DeletePayload) => Promise<unknown>;
    readonly topicsCreate: (payload: CreateTopicConsumable) => Promise<Topic>;
    readonly topicsGetTopicsBySubject: (subject_id: UUID) => Promise<Topic[]>;
    readonly topicsGet: (id: UUID) => Promise<Topic>;
    readonly topicsUpdate: (payload: CreateTopicConsumable, id: UUID) => Promise<Topic>;
    readonly userF: () => Promise<unknown>;
    readonly userGetStudent: () => Promise<Student>;
    readonly userCreateStudent: (payload: StudentData) => Promise<Student>;
    readonly userGetTeacher: () => Promise<Teacher>;
    readonly userCreateTeacher: () => Promise<Teacher>;
    readonly utilsGetCategory: () => Promise<SubjectsCatergoryEnum[]>;
    readonly utilsGetGrades: () => Promise<Grade[]>;
    readonly utilsGetPlan: () => Promise<PlanEnum[]>;
    readonly utilsGetPlaylist: () => Promise<PlaylistMediaEnum[]>;
    readonly utilsGetSubjects: () => Promise<SubjectsEnum[]>;
};
declare type MutationConfigs = {
    useAssessmentCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentAnswerCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentAnswerUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerDelete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentComplete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentComplete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentComplete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentQuestionCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentQuestionCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentQuestionCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentQuestionUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentQuestionUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentQuestionUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentQuestionDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentQuestionDelete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentStart?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentStart"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentStart"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAuthenticationLogin?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["authenticationLogin"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["authenticationLogin"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAuthenticationRegister?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["authenticationRegister"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["authenticationRegister"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useClassroomCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["classroomCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["classroomCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useClassroomDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["classroomDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["classroomDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useClassroomUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["classroomUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["classroomUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useDocumentCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["documentCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["documentCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseAnswerCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseAnswerCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseAnswerCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseAnswerUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseAnswerUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseAnswerUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseAnswerDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseAnswerDelete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseComplete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseComplete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseComplete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseQuestionCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseQuestionCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseQuestionCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseQuestionUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseQuestionUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseQuestionUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseQuestionDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseQuestionDelete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseStart?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseStart"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseStart"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useFilesCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["filesCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["filesCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useFilesComplete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["filesComplete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerResponseCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerResponseCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentAnswerResponseCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerResponseCreateLong?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerResponseCreateLong"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentAnswerResponseCreateLong"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseAnswerResponseCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseAnswerResponseCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseAnswerResponseCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentGradingCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentGradingCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentGradingCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentGradingCompleteMarking?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentGradingCompleteMarking"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentGradingMark?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentGradingMark"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentGradingMark"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentGradingMarkLong?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentGradingMarkLong"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentGradingMarkLong"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseGradingCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseGradingCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseGradingCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseGradingMark?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseGradingMark"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseGradingMark"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useLessonsCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["lessonsCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["lessonsCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useLessonsDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["lessonsDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["lessonsDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useLessonsUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["lessonsUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["lessonsUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useMediaCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["mediaCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["mediaCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useMediaDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["mediaDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["mediaDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useMediaUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["mediaUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["mediaUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useNotesCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["notesCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["notesCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useNotesDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["notesDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["notesDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useNotesUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["notesUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["notesUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    usePlaylistCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["playlistCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["playlistCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    usePlaylistDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["playlistDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["playlistDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    usePlaylistUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["playlistUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["playlistUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubjectsDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subjectsDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subjectsDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubjectsCreateClassroomSubject?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subjectsCreateClassroomSubject"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subjectsCreateClassroomSubject"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubjectsCreateSubject?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subjectsCreateSubject"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subjectsCreateSubject"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubjectsUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subjectsUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subjectsUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubscriptionResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subscriptionResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subscriptionResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubscriptionResourceUserSub?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subscriptionResourceUserSub"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subscriptionResourceUserSub"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useTopicsCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["topicsCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["topicsCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useTopicsDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["topicsDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["topicsDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useTopicsUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["topicsUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["topicsUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useUserF?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["userF"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useUserCreateStudent?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["userCreateStudent"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["userCreateStudent"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useUserCreateTeacher?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["userCreateTeacher"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
};
export {};
