import type { AxiosInstance, AxiosRequestConfig } from "axios";
import { useQuery, useMutation, useQueryClient, type QueryClient, type UseMutationOptions, type UseQueryOptions, type MutationFunction, type UseMutationResult, type UseQueryResult } from "react-query";
export type Assessment = {
    id?: string;
    name?: string;
    description?: string;
    questions?: AssessmentQuestion[];
};
export type AssessmentAnswer = {
    persistent?: boolean;
    id?: string;
    answer?: string;
    correctAnswer?: boolean;
};
export type AssessmentAnswerResponse = {
    id?: string;
    student?: Student;
    marked?: boolean;
    student_response?: string;
};
export type AssessmentQuestion = {
    id?: string;
    question?: string;
    explanation?: string;
    mark?: number;
    answers?: AssessmentAnswer[];
    is_long_form?: boolean;
};
export type AssessmentReports = {
    id?: string;
    student?: Student;
    status?: MarkingStatusEnum;
    total_marks?: number;
    percentage?: number;
    totalMarkQuestions?: number;
    responses?: AssessmentAnswerResponse[];
};
export type AssessmentStatus = {
    id?: string;
    completeStatus?: CompleteStatus;
    started_at?: string;
    completed_at?: string;
    student?: Student;
};
export type Classroom = {
    id?: string;
    name?: string;
    description?: string;
    subjects?: Subject[];
    level_grade?: Grade;
    teacher?: Teacher;
};
export type ClassroomSubscription = {
    id?: string;
    classroom?: Classroom;
    subscription?: UserSubscription;
};
export type CompleteStatus = "DOING" | "DONE";
export type CreateAssessmentAnswer = {
    question?: UUID;
    answer?: string;
    correct_answer?: boolean;
};
export type CreateAssessmentAnswerResponse = {
    answer?: UUID;
    report?: UUID;
    student_response?: string;
};
export type CreateAssessmentConsumable = {
    name?: string;
    description?: string;
    subject?: UUID;
};
export type CreateAssessmentGrading = {
    assessment?: UUID;
};
export type CreateAssessmentLongAnswerResponse = {
    question?: UUID;
    report?: UUID;
    student_response?: string;
};
export type CreateAssessmentQuestion = {
    assessment?: UUID;
    question?: string;
    explanation?: string;
    mark?: number;
    is_long_form?: boolean;
};
export type CreateAssessmentStatus = {
    assessment?: UUID;
};
export type CreateClassroomConsumable = {
    name?: string;
    description?: string;
    level_grade?: Grade;
};
export type CreateDocument = {
    name?: string;
    description?: string;
    file?: UUID;
    lesson?: UUID;
};
export type CreateExerciseAnswer = {
    question?: UUID;
    answer?: string;
    correct_answer?: boolean;
};
export type CreateExerciseAnswerResponse = {
    answer?: UUID;
    report?: UUID;
};
export type CreateExerciseConsumable = {
    name?: string;
    description?: string;
    lesson?: UUID;
};
export type CreateExerciseGrading = {
    exercise?: UUID;
};
export type CreateExerciseQuestion = {
    exercise?: UUID;
    question?: string;
    explanation?: string;
    mark?: number;
};
export type CreateExerciseStatus = {
    exercise?: UUID;
};
export type CreateFileConsumable = {
    name?: string;
    description?: string;
};
export type CreateFileResponse = {
    path?: URL;
    file?: string;
};
export type CreateLessonConsumable = {
    name?: string;
    description?: string;
    topic?: UUID;
};
export type CreateMedia = {
    name?: string;
    description?: string;
    file?: UUID;
    playlist?: UUID;
};
export type CreateNotesConsumable = {
    name?: string;
    description?: string;
    content?: string;
    lesson?: UUID;
};
export type CreatePlaylistConsumable = {
    name?: string;
    description?: string;
    lesson?: UUID;
    type?: PlaylistMediaEnum;
};
export type CreateSubjects = {
    name?: SubjectsEnum;
    description?: string;
    level?: Grade;
    category?: SubjectsCatergoryEnum;
    classroom?: UUID;
};
export type CreateSubscription = {
    name?: string;
    description?: string;
    cost?: number;
    recurrence_unit?: RecurrenceUnit;
    frequency?: number;
};
export type CreateTopicConsumable = {
    name?: string;
    description?: string;
    subject?: UUID;
};
export type CreateUser = {
    username?: string;
    password?: string;
    phoneNumber?: string;
    birthdate?: string;
    firstName?: string;
    lastName?: string;
    roles?: UserRoles[];
};
export type CreateUserSub = {
    name?: string;
    description?: string;
    subscription?: UUID;
    classroom?: UUID;
    date_billing_start?: string;
};
export type DeletePayload = {
    id?: UUID;
};
export type Document = {
    id?: string;
    file?: File;
};
export type Exercise = {
    id?: string;
    name?: string;
    description?: string;
    questions?: ExerciseQuestion[];
};
export type ExerciseAnswer = {
    id?: string;
    answer?: string;
    correct_answer?: boolean;
};
export type ExerciseAnswerResponse = {
    id?: string;
    student?: Student;
    marked?: boolean;
    student_response?: string;
    answer?: ExerciseAnswer;
};
export type ExerciseQuestion = {
    id?: string;
    question?: string;
    explanation?: string;
    mark?: number;
    answers?: ExerciseAnswer[];
};
export type ExerciseReports = {
    id?: string;
    student?: Student;
    status?: MarkingStatusEnum;
    total_marks?: number;
    percentage?: number;
    totalMarkQuestions?: number;
    responses?: ExerciseAnswerResponse[];
};
export type ExerciseStatus = {
    id?: string;
    completeStatus?: CompleteStatus;
    started_at?: string;
    completed_at?: string;
};
export type File = {
    id?: string;
    name?: string;
    description?: string;
    created_at?: string;
    status?: FileCompleteEnum;
    path?: string;
};
export type FileCompleteEnum = "INCOMPLETE" | "COMPLETE";
export type Grade = "GRADE_ONE" | "GRADE_TWO" | "GRADE_THREE" | "GRADE_FOUR" | "GRADE_FIVE" | "GRADE_SIX" | "GRADE_SEVEN" | "FORM_ONE" | "FORM_TWO" | "FORM_THREE" | "FORM_FOUR" | "FORM_FIVE" | "FORM_SIX";
export type Lesson = {
    id?: string;
    name?: string;
    description?: string;
    topic?: Topic;
};
export type LoginUser = {
    username?: string;
    password?: string;
};
export type MarkAssessment = {
    report?: UUID;
};
export type MarkExercise = {
    report?: UUID;
};
export type MarkLongAssessmentAnswer = {
    report?: UUID;
    response?: UUID;
    mark?: number;
};
export type MarkingStatusEnum = "COMPLETE" | "MARKING" | "STARTED";
export type Media = {
    id?: string;
    file?: File;
    media_type?: PlaylistMediaEnum;
};
export type Notes = {
    id?: string;
    name?: string;
    description?: string;
    content?: string;
};
export type PlanCost = {
    id?: string;
    plan?: SubscriptionPlan;
    recurrence_period?: number;
    recurrence_unit?: RecurrenceUnit;
    cost?: number;
};
export type PlanEnum = "free" | "premium";
export type PlanTag = {
    id?: string;
    tag?: string;
};
export type Playlist = {
    id?: string;
    name?: string;
    lesson?: Lesson;
    type?: PlaylistMediaEnum;
};
export type PlaylistMediaEnum = "video" | "audio";
export type RecurrenceUnit = "MONTH" | "YEAR";
export type Role = {
    id?: string;
    runhareUser?: RunhareUser;
    role?: string;
};
export type RunhareUser = {
    id?: string;
    username: string;
    birthdate?: string;
    email?: string;
    phoneNumber?: string;
    firstName?: string;
    lastName?: string;
    roles?: Role[];
};
export type StatsData = {
    users?: number;
};
export type Student = {
    id?: string;
    username?: string;
    level?: Grade;
};
export type StudentData = {
    level?: Grade;
};
export type Subject = {
    id?: string;
    name?: SubjectsEnum;
    description?: string;
    plan?: PlanEnum;
    level?: Grade;
    classroom?: Classroom;
    topics?: Topic[];
    category?: SubjectsCatergoryEnum;
    teacher?: Teacher;
};
export type SubjectsCatergoryEnum = "Arts" | "Sciences" | "Commercials";
export type SubjectsEnum = "Mathematics" | "Business_Studies" | "Combined_Science" | "Physics" | "Chemistry" | "Computer_Science" | "English" | "Geography" | "Accounting" | "Economics" | "Biology" | "Commerce";
export type SubscriptionPlan = {
    id?: string;
    name?: string;
    description?: string;
    tags?: PlanTag[];
    grace_period?: number;
};
export type Task = {
    id?: string;
    created_at?: string;
};
export type Teacher = {
    id?: string;
    username?: string;
    classrooms?: Classroom[];
    subjects?: Subject[];
};
export type TokenResponse = {
    token?: string;
};
export type Topic = {
    id?: string;
    name?: string;
    description?: string;
    subject?: Subject;
};
export type URL = {
    protocol?: string;
    host?: string;
    port?: number;
    file?: string;
    authority?: string;
    ref?: string;
    hashCode?: number;
    defaultPort?: number;
    content?: {};
    serializedHashCode?: number;
};
export type UUID = string;
export type UserRoles = "admin" | "teacher" | "student";
export type UserSubscription = {
    id?: string;
    user?: RunhareUser;
    subscription?: PlanCost;
    date_billing_start?: string;
    date_billing_end?: string;
    date_billing_last?: string;
    date_billing_next?: string;
    active?: boolean;
    cancelled?: boolean;
};
export type AxiosConfig = {
    paramsSerializer?: AxiosRequestConfig["paramsSerializer"];
};
export type Config = {
    mutations?: MutationConfigs;
    axios?: AxiosConfig;
};
export function initialize(axios: AxiosInstance, config?: Config) {
    const requests = makeRequests(axios, config?.axios);
    const queryIds = makeQueryIds();
    return {
        requests,
        queryIds,
        queries: makeQueries(requests, queryIds),
        mutations: makeMutations(requests, config?.mutations)
    };
}
function useRapiniMutation<TData = unknown, TError = unknown, TVariables = void, TContext = unknown>(mutationFn: MutationFunction<TData, TVariables>, config?: (queryClient: QueryClient) => Pick<UseMutationOptions<TData, TError, TVariables, TContext>, "onSuccess" | "onSettled" | "onError">, options?: Omit<UseMutationOptions<TData, TError, TVariables, TContext>, "mutationFn">): UseMutationResult<TData, TError, TVariables, TContext> {
    const { onSuccess, onError, onSettled, ...rest } = options ?? {};
    const queryClient = useQueryClient();
    const conf = config?.(queryClient);
    const mutationOptions: typeof options = {
        onSuccess: (data: TData, variables: TVariables, context?: TContext) => {
            conf?.onSuccess?.(data, variables, context);
            onSuccess?.(data, variables, context);
        },
        onError: (error: TError, variables: TVariables, context?: TContext) => {
            conf?.onError?.(error, variables, context);
            onError?.(error, variables, context);
        },
        onSettled: (data: TData | undefined, error: TError | null, variables: TVariables, context?: TContext) => {
            conf?.onSettled?.(data, error, variables, context);
            onSettled?.(data, error, variables, context);
        },
        ...rest
    };
    return useMutation(mutationFn, mutationOptions);
}
function nullIfUndefined<T>(value: T): T | null {
    return typeof value === "undefined" ? null : value;
}
function makeQueryIds() {
    return {
        assessmentAnswerList: (q: UUID) => ["assessmentAnswerList", q] as const,
        assessmentQuestionList: (assessment_id: UUID) => ["assessmentQuestionList", assessment_id] as const,
        assessmentList: (subject_id: UUID) => ["assessmentList", subject_id] as const,
        assessmentGet: (id: UUID) => ["assessmentGet", id] as const,
        classroomGetByStudentLevel: () => ["classroomGetByStudentLevel"] as const,
        classroomGetTeacherId: () => ["classroomGetTeacherId"] as const,
        classroomGet: (id: UUID) => ["classroomGet", id] as const,
        documentGetByLesson: (id: UUID) => ["documentGetByLesson", id] as const,
        documentGet: (id: UUID) => ["documentGet", id] as const,
        exerciseAnswerList: (q: UUID) => ["exerciseAnswerList", q] as const,
        exerciseList: (lesson_id: UUID) => ["exerciseList", lesson_id] as const,
        exerciseQuestionList: (exercise_id: UUID) => ["exerciseQuestionList", exercise_id] as const,
        exerciseGet: (id: UUID) => ["exerciseGet", id] as const,
        filesList: () => ["filesList"] as const,
        filesGet: (id: UUID) => ["filesGet", id] as const,
        assessmentAnswerResponseGetResponseByAnswer: (assessment_answer: UUID) => ["assessmentAnswerResponseGetResponseByAnswer", assessment_answer] as const,
        assessmentGradingGetByAssessment: (assessment_id: UUID) => ["assessmentGradingGetByAssessment", assessment_id] as const,
        assessmentGradingGet: (id: UUID) => ["assessmentGradingGet", id] as const,
        exerciseGradingGetByExercise: (exercise_id: UUID) => ["exerciseGradingGetByExercise", exercise_id] as const,
        exerciseGradingGet: (id: UUID) => ["exerciseGradingGet", id] as const,
        lessonsGetLessonsByTopic: (topic_id: UUID) => ["lessonsGetLessonsByTopic", topic_id] as const,
        lessonsGet: (id: UUID) => ["lessonsGet", id] as const,
        mediaGetByPlaylist: (playlist_id: UUID) => ["mediaGetByPlaylist", playlist_id] as const,
        mediaGet: (id: UUID) => ["mediaGet", id] as const,
        notesGetNotesByLesson: (lesson_id: UUID) => ["notesGetNotesByLesson", lesson_id] as const,
        notesGet: (id: UUID) => ["notesGet", id] as const,
        playlistGetPlaylistsByLesson: (lesson_id: UUID) => ["playlistGetPlaylistsByLesson", lesson_id] as const,
        playlistGet: (id: UUID) => ["playlistGet", id] as const,
        statsGetStats: () => ["statsGetStats"] as const,
        subjectsListByClassroom: (classroom_id: UUID) => ["subjectsListByClassroom", classroom_id] as const,
        subjectsGetByStudentLevel: () => ["subjectsGetByStudentLevel"] as const,
        subjectsGet: (id: UUID) => ["subjectsGet", id] as const,
        subjectsGetByTeacher: () => ["subjectsGetByTeacher"] as const,
        taskResourceListAll: () => ["taskResourceListAll"] as const,
        topicsGetTopicsBySubject: (subject_id: UUID) => ["topicsGetTopicsBySubject", subject_id] as const,
        topicsGet: (id: UUID) => ["topicsGet", id] as const,
        userGetStudent: () => ["userGetStudent"] as const,
        userGetTeacher: () => ["userGetTeacher"] as const,
        utilsGetCategory: () => ["utilsGetCategory"] as const,
        utilsGetGrades: () => ["utilsGetGrades"] as const,
        utilsGetPlan: () => ["utilsGetPlan"] as const,
        utilsGetPlaylist: () => ["utilsGetPlaylist"] as const,
        utilsGetSubjects: () => ["utilsGetSubjects"] as const
    } as const;
}
function makeRequests(axios: AxiosInstance, config?: AxiosConfig) {
    return {
        assessmentDelete: (payload: DeletePayload) => axios.request<unknown>({
            method: "delete",
            url: `/v1/api/assessments`,
            data: payload
        }).then(res => res.data),
        assessmentCreate: (payload: CreateAssessmentConsumable) => axios.request<Assessment>({
            method: "post",
            url: `/v1/api/assessments`,
            data: payload
        }).then(res => res.data),
        assessmentAnswerCreate: (payload: CreateAssessmentAnswer) => axios.request<AssessmentAnswer>({
            method: "post",
            url: `/v1/api/assessments/a`,
            data: payload
        }).then(res => res.data),
        assessmentAnswerDelete: (id: UUID) => axios.request<{}>({
            method: "delete",
            url: `/v1/api/assessments/a/${id}`
        }).then(res => res.data),
        assessmentAnswerUpdate: (payload: CreateAssessmentAnswer, id: UUID) => axios.request<AssessmentAnswer>({
            method: "put",
            url: `/v1/api/assessments/a/${id}`,
            data: payload
        }).then(res => res.data),
        assessmentAnswerList: (q: UUID) => axios.request<AssessmentAnswer[]>({
            method: "get",
            url: `/v1/api/assessments/a/${q}`
        }).then(res => res.data),
        assessmentComplete: (payload: CreateAssessmentStatus) => axios.request<AssessmentStatus>({
            method: "post",
            url: `/v1/api/assessments/complete`,
            data: payload
        }).then(res => res.data),
        assessmentQuestionCreate: (payload: CreateAssessmentQuestion) => axios.request<AssessmentQuestion>({
            method: "post",
            url: `/v1/api/assessments/q`,
            data: payload
        }).then(res => res.data),
        assessmentQuestionList: (assessment_id: UUID) => axios.request<AssessmentQuestion[]>({
            method: "get",
            url: `/v1/api/assessments/q/${assessment_id}`
        }).then(res => res.data),
        assessmentQuestionDelete: (id: UUID) => axios.request<{}>({
            method: "delete",
            url: `/v1/api/assessments/q/${id}`
        }).then(res => res.data),
        assessmentQuestionUpdate: (payload: CreateAssessmentQuestion, id: UUID) => axios.request<AssessmentQuestion>({
            method: "put",
            url: `/v1/api/assessments/q/${id}`,
            data: payload
        }).then(res => res.data),
        assessmentList: (subject_id: UUID) => axios.request<Assessment[]>({
            method: "get",
            url: `/v1/api/assessments/s/${subject_id}`
        }).then(res => res.data),
        assessmentStart: (payload: CreateAssessmentStatus) => axios.request<AssessmentStatus>({
            method: "post",
            url: `/v1/api/assessments/start`,
            data: payload
        }).then(res => res.data),
        assessmentGet: (id: UUID) => axios.request<Assessment>({
            method: "get",
            url: `/v1/api/assessments/${id}`
        }).then(res => res.data),
        assessmentUpdate: (payload: CreateAssessmentConsumable, id: UUID) => axios.request<Assessment>({
            method: "put",
            url: `/v1/api/assessments/${id}`,
            data: payload
        }).then(res => res.data),
        authenticationLogin: (payload: LoginUser) => axios.request<TokenResponse>({
            method: "post",
            url: `/v1/api/auth/login`,
            data: payload
        }).then(res => res.data),
        authenticationRegister: (payload: CreateUser) => axios.request<TokenResponse>({
            method: "post",
            url: `/v1/api/auth/register`,
            data: payload
        }).then(res => res.data),
        classroomDelete: (payload: DeletePayload) => axios.request<{}>({
            method: "delete",
            url: `/v1/api/classrooms`,
            data: payload
        }).then(res => res.data),
        classroomCreate: (payload: CreateClassroomConsumable) => axios.request<Classroom>({
            method: "post",
            url: `/v1/api/classrooms`,
            data: payload
        }).then(res => res.data),
        classroomGetByStudentLevel: () => axios.request<Classroom[]>({
            method: "get",
            url: `/v1/api/classrooms/s`
        }).then(res => res.data),
        classroomGetTeacherId: () => axios.request<Classroom[]>({
            method: "get",
            url: `/v1/api/classrooms/t`
        }).then(res => res.data),
        classroomGet: (id: UUID) => axios.request<Classroom>({
            method: "get",
            url: `/v1/api/classrooms/${id}`
        }).then(res => res.data),
        classroomUpdate: (payload: CreateClassroomConsumable, id: UUID) => axios.request<Classroom>({
            method: "put",
            url: `/v1/api/classrooms/${id}`,
            data: payload
        }).then(res => res.data),
        documentCreate: (payload: CreateDocument) => axios.request<Document>({
            method: "post",
            url: `/v1/api/document`,
            data: payload
        }).then(res => res.data),
        documentGetByLesson: (id: UUID) => axios.request<Document[]>({
            method: "get",
            url: `/v1/api/document/l/${id}`
        }).then(res => res.data),
        documentGet: (id: UUID) => axios.request<Document>({
            method: "get",
            url: `/v1/api/document/${id}`
        }).then(res => res.data),
        exerciseDelete: (payload: DeletePayload) => axios.request<unknown>({
            method: "delete",
            url: `/v1/api/exercises`,
            data: payload
        }).then(res => res.data),
        exerciseCreate: (payload: CreateExerciseConsumable) => axios.request<Exercise>({
            method: "post",
            url: `/v1/api/exercises`,
            data: payload
        }).then(res => res.data),
        exerciseAnswerCreate: (payload: CreateExerciseAnswer) => axios.request<ExerciseAnswer>({
            method: "post",
            url: `/v1/api/exercises/a`,
            data: payload
        }).then(res => res.data),
        exerciseAnswerDelete: (id: UUID) => axios.request<{}>({
            method: "delete",
            url: `/v1/api/exercises/a/${id}`
        }).then(res => res.data),
        exerciseAnswerUpdate: (payload: CreateExerciseAnswer, id: UUID) => axios.request<ExerciseAnswer>({
            method: "put",
            url: `/v1/api/exercises/a/${id}`,
            data: payload
        }).then(res => res.data),
        exerciseAnswerList: (q: UUID) => axios.request<ExerciseAnswer[]>({
            method: "get",
            url: `/v1/api/exercises/a/${q}`
        }).then(res => res.data),
        exerciseComplete: (payload: CreateExerciseStatus) => axios.request<ExerciseStatus>({
            method: "post",
            url: `/v1/api/exercises/complete`,
            data: payload
        }).then(res => res.data),
        exerciseList: (lesson_id: UUID) => axios.request<Exercise[]>({
            method: "get",
            url: `/v1/api/exercises/l/${lesson_id}`
        }).then(res => res.data),
        exerciseQuestionCreate: (payload: CreateExerciseQuestion) => axios.request<ExerciseQuestion>({
            method: "post",
            url: `/v1/api/exercises/q`,
            data: payload
        }).then(res => res.data),
        exerciseQuestionList: (exercise_id: UUID) => axios.request<ExerciseQuestion[]>({
            method: "get",
            url: `/v1/api/exercises/q/${exercise_id}`
        }).then(res => res.data),
        exerciseQuestionDelete: (id: UUID) => axios.request<{}>({
            method: "delete",
            url: `/v1/api/exercises/q/${id}`
        }).then(res => res.data),
        exerciseQuestionUpdate: (payload: CreateExerciseQuestion, id: UUID) => axios.request<ExerciseQuestion>({
            method: "put",
            url: `/v1/api/exercises/q/${id}`,
            data: payload
        }).then(res => res.data),
        exerciseStart: (payload: CreateExerciseStatus) => axios.request<ExerciseStatus>({
            method: "post",
            url: `/v1/api/exercises/start`,
            data: payload
        }).then(res => res.data),
        exerciseGet: (id: UUID) => axios.request<Exercise>({
            method: "get",
            url: `/v1/api/exercises/${id}`
        }).then(res => res.data),
        exerciseUpdate: (payload: CreateExerciseConsumable, id: UUID) => axios.request<Exercise>({
            method: "put",
            url: `/v1/api/exercises/${id}`,
            data: payload
        }).then(res => res.data),
        filesList: () => axios.request<File[]>({
            method: "get",
            url: `/v1/api/files`
        }).then(res => res.data),
        filesCreate: (payload: CreateFileConsumable) => axios.request<CreateFileResponse>({
            method: "post",
            url: `/v1/api/files`,
            data: payload
        }).then(res => res.data),
        filesComplete: (id: UUID) => axios.request<File>({
            method: "post",
            url: `/v1/api/files/complete/${id}`
        }).then(res => res.data),
        filesGet: (id: UUID) => axios.request<File>({
            method: "get",
            url: `/v1/api/files/${id}`
        }).then(res => res.data),
        assessmentAnswerResponseCreate: (payload: CreateAssessmentAnswerResponse) => axios.request<AssessmentAnswerResponse>({
            method: "post",
            url: `/v1/api/g/answer/a`,
            data: payload
        }).then(res => res.data),
        assessmentAnswerResponseCreateLong: (payload: CreateAssessmentLongAnswerResponse) => axios.request<AssessmentAnswerResponse>({
            method: "post",
            url: `/v1/api/g/answer/a/l`,
            data: payload
        }).then(res => res.data),
        assessmentAnswerResponseGetResponseByAnswer: (assessment_answer: UUID) => axios.request<AssessmentAnswerResponse>({
            method: "get",
            url: `/v1/api/g/answer/a/${assessment_answer}`
        }).then(res => res.data),
        exerciseAnswerResponseCreate: (payload: CreateExerciseAnswerResponse) => axios.request<ExerciseAnswerResponse>({
            method: "post",
            url: `/v1/api/g/answer/e`,
            data: payload
        }).then(res => res.data),
        assessmentGradingCreate: (payload: CreateAssessmentGrading) => axios.request<AssessmentReports>({
            method: "post",
            url: `/v1/api/grading/a`,
            data: payload
        }).then(res => res.data),
        assessmentGradingGetByAssessment: (assessment_id: UUID) => axios.request<AssessmentReports[]>({
            method: "get",
            url: `/v1/api/grading/a/a/${assessment_id}`
        }).then(res => res.data),
        assessmentGradingCompleteMarking: (report_id: UUID) => axios.request<AssessmentReports>({
            method: "post",
            url: `/v1/api/grading/a/complete/marking/${report_id}`
        }).then(res => res.data),
        assessmentGradingMark: (payload: MarkAssessment) => axios.request<AssessmentReports>({
            method: "post",
            url: `/v1/api/grading/a/mark`,
            data: payload
        }).then(res => res.data),
        assessmentGradingMarkLong: (payload: MarkLongAssessmentAnswer) => axios.request<AssessmentReports>({
            method: "post",
            url: `/v1/api/grading/a/mark/l`,
            data: payload
        }).then(res => res.data),
        assessmentGradingGet: (id: UUID) => axios.request<AssessmentReports[]>({
            method: "get",
            url: `/v1/api/grading/a/${id}`
        }).then(res => res.data),
        exerciseGradingCreate: (payload: CreateExerciseGrading) => axios.request<ExerciseReports>({
            method: "post",
            url: `/v1/api/grading/e`,
            data: payload
        }).then(res => res.data),
        exerciseGradingGetByExercise: (exercise_id: UUID) => axios.request<ExerciseReports[]>({
            method: "get",
            url: `/v1/api/grading/e/e/${exercise_id}`
        }).then(res => res.data),
        exerciseGradingMark: (payload: MarkExercise) => axios.request<ExerciseReports>({
            method: "post",
            url: `/v1/api/grading/e/mark`,
            data: payload
        }).then(res => res.data),
        exerciseGradingGet: (id: UUID) => axios.request<ExerciseReports>({
            method: "get",
            url: `/v1/api/grading/e/${id}`
        }).then(res => res.data),
        lessonsDelete: (payload: DeletePayload) => axios.request<unknown>({
            method: "delete",
            url: `/v1/api/lessons`,
            data: payload
        }).then(res => res.data),
        lessonsCreate: (payload: CreateLessonConsumable) => axios.request<Lesson>({
            method: "post",
            url: `/v1/api/lessons`,
            data: payload
        }).then(res => res.data),
        lessonsGetLessonsByTopic: (topic_id: UUID) => axios.request<Lesson[]>({
            method: "get",
            url: `/v1/api/lessons/t/${topic_id}`
        }).then(res => res.data),
        lessonsGet: (id: UUID) => axios.request<Lesson>({
            method: "get",
            url: `/v1/api/lessons/${id}`
        }).then(res => res.data),
        lessonsUpdate: (payload: CreateLessonConsumable, id: UUID) => axios.request<Lesson>({
            method: "put",
            url: `/v1/api/lessons/${id}`,
            data: payload
        }).then(res => res.data),
        mediaDelete: (payload: DeletePayload) => axios.request<unknown>({
            method: "delete",
            url: `/v1/api/media`,
            data: payload
        }).then(res => res.data),
        mediaCreate: (payload: CreateMedia) => axios.request<Media>({
            method: "post",
            url: `/v1/api/media`,
            data: payload
        }).then(res => res.data),
        mediaGetByPlaylist: (playlist_id: UUID) => axios.request<Media[]>({
            method: "get",
            url: `/v1/api/media/p/${playlist_id}`
        }).then(res => res.data),
        mediaGet: (id: UUID) => axios.request<Media>({
            method: "get",
            url: `/v1/api/media/${id}`
        }).then(res => res.data),
        mediaUpdate: (payload: CreateMedia, id: UUID) => axios.request<Media>({
            method: "put",
            url: `/v1/api/media/${id}`,
            data: payload
        }).then(res => res.data),
        notesDelete: (payload: DeletePayload) => axios.request<unknown>({
            method: "delete",
            url: `/v1/api/notes`,
            data: payload
        }).then(res => res.data),
        notesCreate: (payload: CreateNotesConsumable) => axios.request<Notes>({
            method: "post",
            url: `/v1/api/notes`,
            data: payload
        }).then(res => res.data),
        notesGetNotesByLesson: (lesson_id: UUID) => axios.request<Notes[]>({
            method: "get",
            url: `/v1/api/notes/n/${lesson_id}`
        }).then(res => res.data),
        notesGet: (id: UUID) => axios.request<Notes>({
            method: "get",
            url: `/v1/api/notes/${id}`
        }).then(res => res.data),
        notesUpdate: (payload: CreateNotesConsumable, id: UUID) => axios.request<Notes>({
            method: "put",
            url: `/v1/api/notes/${id}`,
            data: payload
        }).then(res => res.data),
        playlistDelete: (payload: DeletePayload) => axios.request<unknown>({
            method: "delete",
            url: `/v1/api/playlist`,
            data: payload
        }).then(res => res.data),
        playlistCreate: (payload: CreatePlaylistConsumable) => axios.request<Playlist>({
            method: "post",
            url: `/v1/api/playlist`,
            data: payload
        }).then(res => res.data),
        playlistGetPlaylistsByLesson: (lesson_id: UUID) => axios.request<Playlist[]>({
            method: "get",
            url: `/v1/api/playlist/l/${lesson_id}`
        }).then(res => res.data),
        playlistGet: (id: UUID) => axios.request<Playlist>({
            method: "get",
            url: `/v1/api/playlist/${id}`
        }).then(res => res.data),
        playlistUpdate: (payload: CreatePlaylistConsumable, id: UUID) => axios.request<Playlist>({
            method: "put",
            url: `/v1/api/playlist/${id}`,
            data: payload
        }).then(res => res.data),
        statsGetStats: () => axios.request<StatsData>({
            method: "get",
            url: `/v1/api/stats`
        }).then(res => res.data),
        subjectsDelete: (payload: DeletePayload) => axios.request<unknown>({
            method: "delete",
            url: `/v1/api/subjects`,
            data: payload
        }).then(res => res.data),
        subjectsCreateClassroomSubject: (payload: CreateSubjects) => axios.request<Subject>({
            method: "post",
            url: `/v1/api/subjects/c`,
            data: payload
        }).then(res => res.data),
        subjectsListByClassroom: (classroom_id: UUID) => axios.request<Subject[]>({
            method: "get",
            url: `/v1/api/subjects/c/${classroom_id}`
        }).then(res => res.data),
        subjectsGetByStudentLevel: () => axios.request<Subject[]>({
            method: "get",
            url: `/v1/api/subjects/s`
        }).then(res => res.data),
        subjectsCreateSubject: (payload: CreateSubjects) => axios.request<Subject>({
            method: "post",
            url: `/v1/api/subjects/s`,
            data: payload
        }).then(res => res.data),
        subjectsGet: (id: UUID) => axios.request<Subject>({
            method: "get",
            url: `/v1/api/subjects/s/${id}`
        }).then(res => res.data),
        subjectsGetByTeacher: () => axios.request<Subject[]>({
            method: "get",
            url: `/v1/api/subjects/t`
        }).then(res => res.data),
        subjectsUpdate: (payload: CreateSubjects, id: string) => axios.request<Subject>({
            method: "put",
            url: `/v1/api/subjects/${id}`,
            data: payload
        }).then(res => res.data),
        subscriptionResourceCreate: (payload: CreateSubscription) => axios.request<PlanCost>({
            method: "post",
            url: `/v1/api/subscription`,
            data: payload
        }).then(res => res.data),
        subscriptionResourceUserSub: (payload: CreateUserSub) => axios.request<ClassroomSubscription>({
            method: "post",
            url: `/v1/api/subscription/user_sub`,
            data: payload
        }).then(res => res.data),
        taskResourceListAll: () => axios.request<Task[]>({
            method: "get",
            url: `/v1/api/tasks`
        }).then(res => res.data),
        topicsDelete: (payload: DeletePayload) => axios.request<unknown>({
            method: "delete",
            url: `/v1/api/topics`,
            data: payload
        }).then(res => res.data),
        topicsCreate: (payload: CreateTopicConsumable) => axios.request<Topic>({
            method: "post",
            url: `/v1/api/topics`,
            data: payload
        }).then(res => res.data),
        topicsGetTopicsBySubject: (subject_id: UUID) => axios.request<Topic[]>({
            method: "get",
            url: `/v1/api/topics/s/${subject_id}`
        }).then(res => res.data),
        topicsGet: (id: UUID) => axios.request<Topic>({
            method: "get",
            url: `/v1/api/topics/${id}`
        }).then(res => res.data),
        topicsUpdate: (payload: CreateTopicConsumable, id: UUID) => axios.request<Topic>({
            method: "put",
            url: `/v1/api/topics/${id}`,
            data: payload
        }).then(res => res.data),
        userF: () => axios.request<unknown>({
            method: "post",
            url: `/v1/api/user/f`
        }).then(res => res.data),
        userGetStudent: () => axios.request<Student>({
            method: "get",
            url: `/v1/api/user/student`
        }).then(res => res.data),
        userCreateStudent: (payload: StudentData) => axios.request<Student>({
            method: "post",
            url: `/v1/api/user/student`,
            data: payload
        }).then(res => res.data),
        userGetTeacher: () => axios.request<Teacher>({
            method: "get",
            url: `/v1/api/user/teacher`
        }).then(res => res.data),
        userCreateTeacher: () => axios.request<Teacher>({
            method: "post",
            url: `/v1/api/user/teacher`
        }).then(res => res.data),
        utilsGetCategory: () => axios.request<SubjectsCatergoryEnum[]>({
            method: "get",
            url: `/v1/api/utils/category`
        }).then(res => res.data),
        utilsGetGrades: () => axios.request<Grade[]>({
            method: "get",
            url: `/v1/api/utils/grade`
        }).then(res => res.data),
        utilsGetPlan: () => axios.request<PlanEnum[]>({
            method: "get",
            url: `/v1/api/utils/plan`
        }).then(res => res.data),
        utilsGetPlaylist: () => axios.request<PlaylistMediaEnum[]>({
            method: "get",
            url: `/v1/api/utils/playlist`
        }).then(res => res.data),
        utilsGetSubjects: () => axios.request<SubjectsEnum[]>({
            method: "get",
            url: `/v1/api/utils/subject`
        }).then(res => res.data)
    } as const;
}
function makeQueries(requests: ReturnType<typeof makeRequests>, queryIds: ReturnType<typeof makeQueryIds>) {
    return {
        useAssessmentAnswerList: (q: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.assessmentAnswerList>>, unknown, Awaited<ReturnType<typeof requests.assessmentAnswerList>>, ReturnType<(typeof queryIds)["assessmentAnswerList"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.assessmentAnswerList>>, unknown> => useQuery(queryIds.assessmentAnswerList(q), () => requests.assessmentAnswerList(q), options),
        useAssessmentQuestionList: (assessment_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.assessmentQuestionList>>, unknown, Awaited<ReturnType<typeof requests.assessmentQuestionList>>, ReturnType<(typeof queryIds)["assessmentQuestionList"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.assessmentQuestionList>>, unknown> => useQuery(queryIds.assessmentQuestionList(assessment_id), () => requests.assessmentQuestionList(assessment_id), options),
        useAssessmentList: (subject_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.assessmentList>>, unknown, Awaited<ReturnType<typeof requests.assessmentList>>, ReturnType<(typeof queryIds)["assessmentList"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.assessmentList>>, unknown> => useQuery(queryIds.assessmentList(subject_id), () => requests.assessmentList(subject_id), options),
        useAssessmentGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.assessmentGet>>, unknown, Awaited<ReturnType<typeof requests.assessmentGet>>, ReturnType<(typeof queryIds)["assessmentGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.assessmentGet>>, unknown> => useQuery(queryIds.assessmentGet(id), () => requests.assessmentGet(id), options),
        useClassroomGetByStudentLevel: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.classroomGetByStudentLevel>>, unknown, Awaited<ReturnType<typeof requests.classroomGetByStudentLevel>>, ReturnType<(typeof queryIds)["classroomGetByStudentLevel"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.classroomGetByStudentLevel>>, unknown> => useQuery(queryIds.classroomGetByStudentLevel(), () => requests.classroomGetByStudentLevel(), options),
        useClassroomGetTeacherId: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.classroomGetTeacherId>>, unknown, Awaited<ReturnType<typeof requests.classroomGetTeacherId>>, ReturnType<(typeof queryIds)["classroomGetTeacherId"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.classroomGetTeacherId>>, unknown> => useQuery(queryIds.classroomGetTeacherId(), () => requests.classroomGetTeacherId(), options),
        useClassroomGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.classroomGet>>, unknown, Awaited<ReturnType<typeof requests.classroomGet>>, ReturnType<(typeof queryIds)["classroomGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.classroomGet>>, unknown> => useQuery(queryIds.classroomGet(id), () => requests.classroomGet(id), options),
        useDocumentGetByLesson: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.documentGetByLesson>>, unknown, Awaited<ReturnType<typeof requests.documentGetByLesson>>, ReturnType<(typeof queryIds)["documentGetByLesson"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.documentGetByLesson>>, unknown> => useQuery(queryIds.documentGetByLesson(id), () => requests.documentGetByLesson(id), options),
        useDocumentGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.documentGet>>, unknown, Awaited<ReturnType<typeof requests.documentGet>>, ReturnType<(typeof queryIds)["documentGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.documentGet>>, unknown> => useQuery(queryIds.documentGet(id), () => requests.documentGet(id), options),
        useExerciseAnswerList: (q: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.exerciseAnswerList>>, unknown, Awaited<ReturnType<typeof requests.exerciseAnswerList>>, ReturnType<(typeof queryIds)["exerciseAnswerList"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.exerciseAnswerList>>, unknown> => useQuery(queryIds.exerciseAnswerList(q), () => requests.exerciseAnswerList(q), options),
        useExerciseList: (lesson_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.exerciseList>>, unknown, Awaited<ReturnType<typeof requests.exerciseList>>, ReturnType<(typeof queryIds)["exerciseList"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.exerciseList>>, unknown> => useQuery(queryIds.exerciseList(lesson_id), () => requests.exerciseList(lesson_id), options),
        useExerciseQuestionList: (exercise_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.exerciseQuestionList>>, unknown, Awaited<ReturnType<typeof requests.exerciseQuestionList>>, ReturnType<(typeof queryIds)["exerciseQuestionList"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.exerciseQuestionList>>, unknown> => useQuery(queryIds.exerciseQuestionList(exercise_id), () => requests.exerciseQuestionList(exercise_id), options),
        useExerciseGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.exerciseGet>>, unknown, Awaited<ReturnType<typeof requests.exerciseGet>>, ReturnType<(typeof queryIds)["exerciseGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.exerciseGet>>, unknown> => useQuery(queryIds.exerciseGet(id), () => requests.exerciseGet(id), options),
        useFilesList: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.filesList>>, unknown, Awaited<ReturnType<typeof requests.filesList>>, ReturnType<(typeof queryIds)["filesList"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.filesList>>, unknown> => useQuery(queryIds.filesList(), () => requests.filesList(), options),
        useFilesGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.filesGet>>, unknown, Awaited<ReturnType<typeof requests.filesGet>>, ReturnType<(typeof queryIds)["filesGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.filesGet>>, unknown> => useQuery(queryIds.filesGet(id), () => requests.filesGet(id), options),
        useAssessmentAnswerResponseGetResponseByAnswer: (assessment_answer: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.assessmentAnswerResponseGetResponseByAnswer>>, unknown, Awaited<ReturnType<typeof requests.assessmentAnswerResponseGetResponseByAnswer>>, ReturnType<(typeof queryIds)["assessmentAnswerResponseGetResponseByAnswer"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.assessmentAnswerResponseGetResponseByAnswer>>, unknown> => useQuery(queryIds.assessmentAnswerResponseGetResponseByAnswer(assessment_answer), () => requests.assessmentAnswerResponseGetResponseByAnswer(assessment_answer), options),
        useAssessmentGradingGetByAssessment: (assessment_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.assessmentGradingGetByAssessment>>, unknown, Awaited<ReturnType<typeof requests.assessmentGradingGetByAssessment>>, ReturnType<(typeof queryIds)["assessmentGradingGetByAssessment"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.assessmentGradingGetByAssessment>>, unknown> => useQuery(queryIds.assessmentGradingGetByAssessment(assessment_id), () => requests.assessmentGradingGetByAssessment(assessment_id), options),
        useAssessmentGradingGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.assessmentGradingGet>>, unknown, Awaited<ReturnType<typeof requests.assessmentGradingGet>>, ReturnType<(typeof queryIds)["assessmentGradingGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.assessmentGradingGet>>, unknown> => useQuery(queryIds.assessmentGradingGet(id), () => requests.assessmentGradingGet(id), options),
        useExerciseGradingGetByExercise: (exercise_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.exerciseGradingGetByExercise>>, unknown, Awaited<ReturnType<typeof requests.exerciseGradingGetByExercise>>, ReturnType<(typeof queryIds)["exerciseGradingGetByExercise"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.exerciseGradingGetByExercise>>, unknown> => useQuery(queryIds.exerciseGradingGetByExercise(exercise_id), () => requests.exerciseGradingGetByExercise(exercise_id), options),
        useExerciseGradingGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.exerciseGradingGet>>, unknown, Awaited<ReturnType<typeof requests.exerciseGradingGet>>, ReturnType<(typeof queryIds)["exerciseGradingGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.exerciseGradingGet>>, unknown> => useQuery(queryIds.exerciseGradingGet(id), () => requests.exerciseGradingGet(id), options),
        useLessonsGetLessonsByTopic: (topic_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.lessonsGetLessonsByTopic>>, unknown, Awaited<ReturnType<typeof requests.lessonsGetLessonsByTopic>>, ReturnType<(typeof queryIds)["lessonsGetLessonsByTopic"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.lessonsGetLessonsByTopic>>, unknown> => useQuery(queryIds.lessonsGetLessonsByTopic(topic_id), () => requests.lessonsGetLessonsByTopic(topic_id), options),
        useLessonsGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.lessonsGet>>, unknown, Awaited<ReturnType<typeof requests.lessonsGet>>, ReturnType<(typeof queryIds)["lessonsGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.lessonsGet>>, unknown> => useQuery(queryIds.lessonsGet(id), () => requests.lessonsGet(id), options),
        useMediaGetByPlaylist: (playlist_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.mediaGetByPlaylist>>, unknown, Awaited<ReturnType<typeof requests.mediaGetByPlaylist>>, ReturnType<(typeof queryIds)["mediaGetByPlaylist"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.mediaGetByPlaylist>>, unknown> => useQuery(queryIds.mediaGetByPlaylist(playlist_id), () => requests.mediaGetByPlaylist(playlist_id), options),
        useMediaGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.mediaGet>>, unknown, Awaited<ReturnType<typeof requests.mediaGet>>, ReturnType<(typeof queryIds)["mediaGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.mediaGet>>, unknown> => useQuery(queryIds.mediaGet(id), () => requests.mediaGet(id), options),
        useNotesGetNotesByLesson: (lesson_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.notesGetNotesByLesson>>, unknown, Awaited<ReturnType<typeof requests.notesGetNotesByLesson>>, ReturnType<(typeof queryIds)["notesGetNotesByLesson"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.notesGetNotesByLesson>>, unknown> => useQuery(queryIds.notesGetNotesByLesson(lesson_id), () => requests.notesGetNotesByLesson(lesson_id), options),
        useNotesGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.notesGet>>, unknown, Awaited<ReturnType<typeof requests.notesGet>>, ReturnType<(typeof queryIds)["notesGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.notesGet>>, unknown> => useQuery(queryIds.notesGet(id), () => requests.notesGet(id), options),
        usePlaylistGetPlaylistsByLesson: (lesson_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.playlistGetPlaylistsByLesson>>, unknown, Awaited<ReturnType<typeof requests.playlistGetPlaylistsByLesson>>, ReturnType<(typeof queryIds)["playlistGetPlaylistsByLesson"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.playlistGetPlaylistsByLesson>>, unknown> => useQuery(queryIds.playlistGetPlaylistsByLesson(lesson_id), () => requests.playlistGetPlaylistsByLesson(lesson_id), options),
        usePlaylistGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.playlistGet>>, unknown, Awaited<ReturnType<typeof requests.playlistGet>>, ReturnType<(typeof queryIds)["playlistGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.playlistGet>>, unknown> => useQuery(queryIds.playlistGet(id), () => requests.playlistGet(id), options),
        useStatsGetStats: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.statsGetStats>>, unknown, Awaited<ReturnType<typeof requests.statsGetStats>>, ReturnType<(typeof queryIds)["statsGetStats"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.statsGetStats>>, unknown> => useQuery(queryIds.statsGetStats(), () => requests.statsGetStats(), options),
        useSubjectsListByClassroom: (classroom_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.subjectsListByClassroom>>, unknown, Awaited<ReturnType<typeof requests.subjectsListByClassroom>>, ReturnType<(typeof queryIds)["subjectsListByClassroom"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.subjectsListByClassroom>>, unknown> => useQuery(queryIds.subjectsListByClassroom(classroom_id), () => requests.subjectsListByClassroom(classroom_id), options),
        useSubjectsGetByStudentLevel: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.subjectsGetByStudentLevel>>, unknown, Awaited<ReturnType<typeof requests.subjectsGetByStudentLevel>>, ReturnType<(typeof queryIds)["subjectsGetByStudentLevel"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.subjectsGetByStudentLevel>>, unknown> => useQuery(queryIds.subjectsGetByStudentLevel(), () => requests.subjectsGetByStudentLevel(), options),
        useSubjectsGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.subjectsGet>>, unknown, Awaited<ReturnType<typeof requests.subjectsGet>>, ReturnType<(typeof queryIds)["subjectsGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.subjectsGet>>, unknown> => useQuery(queryIds.subjectsGet(id), () => requests.subjectsGet(id), options),
        useSubjectsGetByTeacher: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.subjectsGetByTeacher>>, unknown, Awaited<ReturnType<typeof requests.subjectsGetByTeacher>>, ReturnType<(typeof queryIds)["subjectsGetByTeacher"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.subjectsGetByTeacher>>, unknown> => useQuery(queryIds.subjectsGetByTeacher(), () => requests.subjectsGetByTeacher(), options),
        useTaskResourceListAll: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.taskResourceListAll>>, unknown, Awaited<ReturnType<typeof requests.taskResourceListAll>>, ReturnType<(typeof queryIds)["taskResourceListAll"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.taskResourceListAll>>, unknown> => useQuery(queryIds.taskResourceListAll(), () => requests.taskResourceListAll(), options),
        useTopicsGetTopicsBySubject: (subject_id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.topicsGetTopicsBySubject>>, unknown, Awaited<ReturnType<typeof requests.topicsGetTopicsBySubject>>, ReturnType<(typeof queryIds)["topicsGetTopicsBySubject"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.topicsGetTopicsBySubject>>, unknown> => useQuery(queryIds.topicsGetTopicsBySubject(subject_id), () => requests.topicsGetTopicsBySubject(subject_id), options),
        useTopicsGet: (id: UUID, options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.topicsGet>>, unknown, Awaited<ReturnType<typeof requests.topicsGet>>, ReturnType<(typeof queryIds)["topicsGet"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.topicsGet>>, unknown> => useQuery(queryIds.topicsGet(id), () => requests.topicsGet(id), options),
        useUserGetStudent: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.userGetStudent>>, unknown, Awaited<ReturnType<typeof requests.userGetStudent>>, ReturnType<(typeof queryIds)["userGetStudent"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.userGetStudent>>, unknown> => useQuery(queryIds.userGetStudent(), () => requests.userGetStudent(), options),
        useUserGetTeacher: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.userGetTeacher>>, unknown, Awaited<ReturnType<typeof requests.userGetTeacher>>, ReturnType<(typeof queryIds)["userGetTeacher"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.userGetTeacher>>, unknown> => useQuery(queryIds.userGetTeacher(), () => requests.userGetTeacher(), options),
        useUtilsGetCategory: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.utilsGetCategory>>, unknown, Awaited<ReturnType<typeof requests.utilsGetCategory>>, ReturnType<(typeof queryIds)["utilsGetCategory"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.utilsGetCategory>>, unknown> => useQuery(queryIds.utilsGetCategory(), () => requests.utilsGetCategory(), options),
        useUtilsGetGrades: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.utilsGetGrades>>, unknown, Awaited<ReturnType<typeof requests.utilsGetGrades>>, ReturnType<(typeof queryIds)["utilsGetGrades"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.utilsGetGrades>>, unknown> => useQuery(queryIds.utilsGetGrades(), () => requests.utilsGetGrades(), options),
        useUtilsGetPlan: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.utilsGetPlan>>, unknown, Awaited<ReturnType<typeof requests.utilsGetPlan>>, ReturnType<(typeof queryIds)["utilsGetPlan"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.utilsGetPlan>>, unknown> => useQuery(queryIds.utilsGetPlan(), () => requests.utilsGetPlan(), options),
        useUtilsGetPlaylist: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.utilsGetPlaylist>>, unknown, Awaited<ReturnType<typeof requests.utilsGetPlaylist>>, ReturnType<(typeof queryIds)["utilsGetPlaylist"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.utilsGetPlaylist>>, unknown> => useQuery(queryIds.utilsGetPlaylist(), () => requests.utilsGetPlaylist(), options),
        useUtilsGetSubjects: (options?: Omit<UseQueryOptions<Awaited<ReturnType<typeof requests.utilsGetSubjects>>, unknown, Awaited<ReturnType<typeof requests.utilsGetSubjects>>, ReturnType<(typeof queryIds)["utilsGetSubjects"]>>, "queryKey" | "queryFn">): UseQueryResult<Awaited<ReturnType<typeof requests.utilsGetSubjects>>, unknown> => useQuery(queryIds.utilsGetSubjects(), () => requests.utilsGetSubjects(), options)
    } as const;
}
type MutationConfigs = {
    useAssessmentCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentAnswerCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentAnswerUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerDelete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentComplete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentComplete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentComplete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentQuestionCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentQuestionCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentQuestionCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentQuestionUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentQuestionUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentQuestionUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentQuestionDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentQuestionDelete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentStart?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentStart"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentStart"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAuthenticationLogin?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["authenticationLogin"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["authenticationLogin"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAuthenticationRegister?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["authenticationRegister"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["authenticationRegister"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useClassroomCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["classroomCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["classroomCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useClassroomDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["classroomDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["classroomDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useClassroomUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["classroomUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["classroomUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useDocumentCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["documentCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["documentCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseAnswerCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseAnswerCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseAnswerCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseAnswerUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseAnswerUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseAnswerUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseAnswerDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseAnswerDelete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseComplete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseComplete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseComplete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseQuestionCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseQuestionCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseQuestionCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseQuestionUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseQuestionUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseQuestionUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseQuestionDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseQuestionDelete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseStart?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseStart"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseStart"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useFilesCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["filesCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["filesCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useFilesComplete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["filesComplete"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerResponseCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerResponseCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentAnswerResponseCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentAnswerResponseCreateLong?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentAnswerResponseCreateLong"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentAnswerResponseCreateLong"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseAnswerResponseCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseAnswerResponseCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseAnswerResponseCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentGradingCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentGradingCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentGradingCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentGradingCompleteMarking?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentGradingCompleteMarking"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentGradingMark?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentGradingMark"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentGradingMark"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useAssessmentGradingMarkLong?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["assessmentGradingMarkLong"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["assessmentGradingMarkLong"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseGradingCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseGradingCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseGradingCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useExerciseGradingMark?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["exerciseGradingMark"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["exerciseGradingMark"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useLessonsCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["lessonsCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["lessonsCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useLessonsDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["lessonsDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["lessonsDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useLessonsUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["lessonsUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["lessonsUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useMediaCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["mediaCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["mediaCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useMediaDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["mediaDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["mediaDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useMediaUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["mediaUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["mediaUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useNotesCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["notesCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["notesCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useNotesDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["notesDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["notesDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useNotesUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["notesUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["notesUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    usePlaylistCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["playlistCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["playlistCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    usePlaylistDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["playlistDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["playlistDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    usePlaylistUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["playlistUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["playlistUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubjectsDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subjectsDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subjectsDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubjectsCreateClassroomSubject?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subjectsCreateClassroomSubject"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subjectsCreateClassroomSubject"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubjectsCreateSubject?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subjectsCreateSubject"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subjectsCreateSubject"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubjectsUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subjectsUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subjectsUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubscriptionResourceCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subscriptionResourceCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subscriptionResourceCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useSubscriptionResourceUserSub?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["subscriptionResourceUserSub"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["subscriptionResourceUserSub"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useTopicsCreate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["topicsCreate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["topicsCreate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useTopicsDelete?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["topicsDelete"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["topicsDelete"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useTopicsUpdate?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["topicsUpdate"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["topicsUpdate"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useUserF?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["userF"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
    useUserCreateStudent?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["userCreateStudent"]>>, unknown, Parameters<ReturnType<typeof makeRequests>["userCreateStudent"]>[0], unknown>, "onSuccess" | "onSettled" | "onError">;
    useUserCreateTeacher?: (queryClient: QueryClient) => Pick<UseMutationOptions<Awaited<ReturnType<ReturnType<typeof makeRequests>["userCreateTeacher"]>>, unknown, unknown, unknown>, "onSuccess" | "onSettled" | "onError">;
};
function makeMutations(requests: ReturnType<typeof makeRequests>, config?: Config["mutations"]) {
    return {
        useAssessmentCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentCreate>>, unknown, Parameters<typeof requests.assessmentCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentCreate>>, unknown, Parameters<typeof requests.assessmentCreate>[0]>(payload => requests.assessmentCreate(payload), config?.useAssessmentCreate, options),
        useAssessmentDelete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentDelete>>, unknown, Parameters<typeof requests.assessmentDelete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentDelete>>, unknown, Parameters<typeof requests.assessmentDelete>[0]>(payload => requests.assessmentDelete(payload), config?.useAssessmentDelete, options),
        useAssessmentAnswerCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentAnswerCreate>>, unknown, Parameters<typeof requests.assessmentAnswerCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentAnswerCreate>>, unknown, Parameters<typeof requests.assessmentAnswerCreate>[0]>(payload => requests.assessmentAnswerCreate(payload), config?.useAssessmentAnswerCreate, options),
        useAssessmentAnswerUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentAnswerUpdate>>, unknown, Parameters<typeof requests.assessmentAnswerUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentAnswerUpdate>>, unknown, Parameters<typeof requests.assessmentAnswerUpdate>[0]>(payload => requests.assessmentAnswerUpdate(payload, id), config?.useAssessmentAnswerUpdate, options),
        useAssessmentAnswerDelete: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentAnswerDelete>>, unknown, unknown, unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentAnswerDelete>>, unknown, unknown>(() => requests.assessmentAnswerDelete(id), config?.useAssessmentAnswerDelete, options),
        useAssessmentComplete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentComplete>>, unknown, Parameters<typeof requests.assessmentComplete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentComplete>>, unknown, Parameters<typeof requests.assessmentComplete>[0]>(payload => requests.assessmentComplete(payload), config?.useAssessmentComplete, options),
        useAssessmentQuestionCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentQuestionCreate>>, unknown, Parameters<typeof requests.assessmentQuestionCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentQuestionCreate>>, unknown, Parameters<typeof requests.assessmentQuestionCreate>[0]>(payload => requests.assessmentQuestionCreate(payload), config?.useAssessmentQuestionCreate, options),
        useAssessmentQuestionUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentQuestionUpdate>>, unknown, Parameters<typeof requests.assessmentQuestionUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentQuestionUpdate>>, unknown, Parameters<typeof requests.assessmentQuestionUpdate>[0]>(payload => requests.assessmentQuestionUpdate(payload, id), config?.useAssessmentQuestionUpdate, options),
        useAssessmentQuestionDelete: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentQuestionDelete>>, unknown, unknown, unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentQuestionDelete>>, unknown, unknown>(() => requests.assessmentQuestionDelete(id), config?.useAssessmentQuestionDelete, options),
        useAssessmentStart: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentStart>>, unknown, Parameters<typeof requests.assessmentStart>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentStart>>, unknown, Parameters<typeof requests.assessmentStart>[0]>(payload => requests.assessmentStart(payload), config?.useAssessmentStart, options),
        useAssessmentUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentUpdate>>, unknown, Parameters<typeof requests.assessmentUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentUpdate>>, unknown, Parameters<typeof requests.assessmentUpdate>[0]>(payload => requests.assessmentUpdate(payload, id), config?.useAssessmentUpdate, options),
        useAuthenticationLogin: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.authenticationLogin>>, unknown, Parameters<typeof requests.authenticationLogin>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.authenticationLogin>>, unknown, Parameters<typeof requests.authenticationLogin>[0]>(payload => requests.authenticationLogin(payload), config?.useAuthenticationLogin, options),
        useAuthenticationRegister: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.authenticationRegister>>, unknown, Parameters<typeof requests.authenticationRegister>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.authenticationRegister>>, unknown, Parameters<typeof requests.authenticationRegister>[0]>(payload => requests.authenticationRegister(payload), config?.useAuthenticationRegister, options),
        useClassroomCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.classroomCreate>>, unknown, Parameters<typeof requests.classroomCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.classroomCreate>>, unknown, Parameters<typeof requests.classroomCreate>[0]>(payload => requests.classroomCreate(payload), config?.useClassroomCreate, options),
        useClassroomDelete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.classroomDelete>>, unknown, Parameters<typeof requests.classroomDelete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.classroomDelete>>, unknown, Parameters<typeof requests.classroomDelete>[0]>(payload => requests.classroomDelete(payload), config?.useClassroomDelete, options),
        useClassroomUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.classroomUpdate>>, unknown, Parameters<typeof requests.classroomUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.classroomUpdate>>, unknown, Parameters<typeof requests.classroomUpdate>[0]>(payload => requests.classroomUpdate(payload, id), config?.useClassroomUpdate, options),
        useDocumentCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.documentCreate>>, unknown, Parameters<typeof requests.documentCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.documentCreate>>, unknown, Parameters<typeof requests.documentCreate>[0]>(payload => requests.documentCreate(payload), config?.useDocumentCreate, options),
        useExerciseCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseCreate>>, unknown, Parameters<typeof requests.exerciseCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseCreate>>, unknown, Parameters<typeof requests.exerciseCreate>[0]>(payload => requests.exerciseCreate(payload), config?.useExerciseCreate, options),
        useExerciseDelete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseDelete>>, unknown, Parameters<typeof requests.exerciseDelete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseDelete>>, unknown, Parameters<typeof requests.exerciseDelete>[0]>(payload => requests.exerciseDelete(payload), config?.useExerciseDelete, options),
        useExerciseAnswerCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseAnswerCreate>>, unknown, Parameters<typeof requests.exerciseAnswerCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseAnswerCreate>>, unknown, Parameters<typeof requests.exerciseAnswerCreate>[0]>(payload => requests.exerciseAnswerCreate(payload), config?.useExerciseAnswerCreate, options),
        useExerciseAnswerUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseAnswerUpdate>>, unknown, Parameters<typeof requests.exerciseAnswerUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseAnswerUpdate>>, unknown, Parameters<typeof requests.exerciseAnswerUpdate>[0]>(payload => requests.exerciseAnswerUpdate(payload, id), config?.useExerciseAnswerUpdate, options),
        useExerciseAnswerDelete: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseAnswerDelete>>, unknown, unknown, unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseAnswerDelete>>, unknown, unknown>(() => requests.exerciseAnswerDelete(id), config?.useExerciseAnswerDelete, options),
        useExerciseComplete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseComplete>>, unknown, Parameters<typeof requests.exerciseComplete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseComplete>>, unknown, Parameters<typeof requests.exerciseComplete>[0]>(payload => requests.exerciseComplete(payload), config?.useExerciseComplete, options),
        useExerciseQuestionCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseQuestionCreate>>, unknown, Parameters<typeof requests.exerciseQuestionCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseQuestionCreate>>, unknown, Parameters<typeof requests.exerciseQuestionCreate>[0]>(payload => requests.exerciseQuestionCreate(payload), config?.useExerciseQuestionCreate, options),
        useExerciseQuestionUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseQuestionUpdate>>, unknown, Parameters<typeof requests.exerciseQuestionUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseQuestionUpdate>>, unknown, Parameters<typeof requests.exerciseQuestionUpdate>[0]>(payload => requests.exerciseQuestionUpdate(payload, id), config?.useExerciseQuestionUpdate, options),
        useExerciseQuestionDelete: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseQuestionDelete>>, unknown, unknown, unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseQuestionDelete>>, unknown, unknown>(() => requests.exerciseQuestionDelete(id), config?.useExerciseQuestionDelete, options),
        useExerciseStart: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseStart>>, unknown, Parameters<typeof requests.exerciseStart>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseStart>>, unknown, Parameters<typeof requests.exerciseStart>[0]>(payload => requests.exerciseStart(payload), config?.useExerciseStart, options),
        useExerciseUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseUpdate>>, unknown, Parameters<typeof requests.exerciseUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseUpdate>>, unknown, Parameters<typeof requests.exerciseUpdate>[0]>(payload => requests.exerciseUpdate(payload, id), config?.useExerciseUpdate, options),
        useFilesCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.filesCreate>>, unknown, Parameters<typeof requests.filesCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.filesCreate>>, unknown, Parameters<typeof requests.filesCreate>[0]>(payload => requests.filesCreate(payload), config?.useFilesCreate, options),
        useFilesComplete: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.filesComplete>>, unknown, unknown, unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.filesComplete>>, unknown, unknown>(() => requests.filesComplete(id), config?.useFilesComplete, options),
        useAssessmentAnswerResponseCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentAnswerResponseCreate>>, unknown, Parameters<typeof requests.assessmentAnswerResponseCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentAnswerResponseCreate>>, unknown, Parameters<typeof requests.assessmentAnswerResponseCreate>[0]>(payload => requests.assessmentAnswerResponseCreate(payload), config?.useAssessmentAnswerResponseCreate, options),
        useAssessmentAnswerResponseCreateLong: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentAnswerResponseCreateLong>>, unknown, Parameters<typeof requests.assessmentAnswerResponseCreateLong>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentAnswerResponseCreateLong>>, unknown, Parameters<typeof requests.assessmentAnswerResponseCreateLong>[0]>(payload => requests.assessmentAnswerResponseCreateLong(payload), config?.useAssessmentAnswerResponseCreateLong, options),
        useExerciseAnswerResponseCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseAnswerResponseCreate>>, unknown, Parameters<typeof requests.exerciseAnswerResponseCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseAnswerResponseCreate>>, unknown, Parameters<typeof requests.exerciseAnswerResponseCreate>[0]>(payload => requests.exerciseAnswerResponseCreate(payload), config?.useExerciseAnswerResponseCreate, options),
        useAssessmentGradingCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentGradingCreate>>, unknown, Parameters<typeof requests.assessmentGradingCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentGradingCreate>>, unknown, Parameters<typeof requests.assessmentGradingCreate>[0]>(payload => requests.assessmentGradingCreate(payload), config?.useAssessmentGradingCreate, options),
        useAssessmentGradingCompleteMarking: (report_id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentGradingCompleteMarking>>, unknown, unknown, unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentGradingCompleteMarking>>, unknown, unknown>(() => requests.assessmentGradingCompleteMarking(report_id), config?.useAssessmentGradingCompleteMarking, options),
        useAssessmentGradingMark: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentGradingMark>>, unknown, Parameters<typeof requests.assessmentGradingMark>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentGradingMark>>, unknown, Parameters<typeof requests.assessmentGradingMark>[0]>(payload => requests.assessmentGradingMark(payload), config?.useAssessmentGradingMark, options),
        useAssessmentGradingMarkLong: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.assessmentGradingMarkLong>>, unknown, Parameters<typeof requests.assessmentGradingMarkLong>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.assessmentGradingMarkLong>>, unknown, Parameters<typeof requests.assessmentGradingMarkLong>[0]>(payload => requests.assessmentGradingMarkLong(payload), config?.useAssessmentGradingMarkLong, options),
        useExerciseGradingCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseGradingCreate>>, unknown, Parameters<typeof requests.exerciseGradingCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseGradingCreate>>, unknown, Parameters<typeof requests.exerciseGradingCreate>[0]>(payload => requests.exerciseGradingCreate(payload), config?.useExerciseGradingCreate, options),
        useExerciseGradingMark: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.exerciseGradingMark>>, unknown, Parameters<typeof requests.exerciseGradingMark>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.exerciseGradingMark>>, unknown, Parameters<typeof requests.exerciseGradingMark>[0]>(payload => requests.exerciseGradingMark(payload), config?.useExerciseGradingMark, options),
        useLessonsCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.lessonsCreate>>, unknown, Parameters<typeof requests.lessonsCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.lessonsCreate>>, unknown, Parameters<typeof requests.lessonsCreate>[0]>(payload => requests.lessonsCreate(payload), config?.useLessonsCreate, options),
        useLessonsDelete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.lessonsDelete>>, unknown, Parameters<typeof requests.lessonsDelete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.lessonsDelete>>, unknown, Parameters<typeof requests.lessonsDelete>[0]>(payload => requests.lessonsDelete(payload), config?.useLessonsDelete, options),
        useLessonsUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.lessonsUpdate>>, unknown, Parameters<typeof requests.lessonsUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.lessonsUpdate>>, unknown, Parameters<typeof requests.lessonsUpdate>[0]>(payload => requests.lessonsUpdate(payload, id), config?.useLessonsUpdate, options),
        useMediaCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.mediaCreate>>, unknown, Parameters<typeof requests.mediaCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.mediaCreate>>, unknown, Parameters<typeof requests.mediaCreate>[0]>(payload => requests.mediaCreate(payload), config?.useMediaCreate, options),
        useMediaDelete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.mediaDelete>>, unknown, Parameters<typeof requests.mediaDelete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.mediaDelete>>, unknown, Parameters<typeof requests.mediaDelete>[0]>(payload => requests.mediaDelete(payload), config?.useMediaDelete, options),
        useMediaUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.mediaUpdate>>, unknown, Parameters<typeof requests.mediaUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.mediaUpdate>>, unknown, Parameters<typeof requests.mediaUpdate>[0]>(payload => requests.mediaUpdate(payload, id), config?.useMediaUpdate, options),
        useNotesCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.notesCreate>>, unknown, Parameters<typeof requests.notesCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.notesCreate>>, unknown, Parameters<typeof requests.notesCreate>[0]>(payload => requests.notesCreate(payload), config?.useNotesCreate, options),
        useNotesDelete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.notesDelete>>, unknown, Parameters<typeof requests.notesDelete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.notesDelete>>, unknown, Parameters<typeof requests.notesDelete>[0]>(payload => requests.notesDelete(payload), config?.useNotesDelete, options),
        useNotesUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.notesUpdate>>, unknown, Parameters<typeof requests.notesUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.notesUpdate>>, unknown, Parameters<typeof requests.notesUpdate>[0]>(payload => requests.notesUpdate(payload, id), config?.useNotesUpdate, options),
        usePlaylistCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.playlistCreate>>, unknown, Parameters<typeof requests.playlistCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.playlistCreate>>, unknown, Parameters<typeof requests.playlistCreate>[0]>(payload => requests.playlistCreate(payload), config?.usePlaylistCreate, options),
        usePlaylistDelete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.playlistDelete>>, unknown, Parameters<typeof requests.playlistDelete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.playlistDelete>>, unknown, Parameters<typeof requests.playlistDelete>[0]>(payload => requests.playlistDelete(payload), config?.usePlaylistDelete, options),
        usePlaylistUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.playlistUpdate>>, unknown, Parameters<typeof requests.playlistUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.playlistUpdate>>, unknown, Parameters<typeof requests.playlistUpdate>[0]>(payload => requests.playlistUpdate(payload, id), config?.usePlaylistUpdate, options),
        useSubjectsDelete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.subjectsDelete>>, unknown, Parameters<typeof requests.subjectsDelete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.subjectsDelete>>, unknown, Parameters<typeof requests.subjectsDelete>[0]>(payload => requests.subjectsDelete(payload), config?.useSubjectsDelete, options),
        useSubjectsCreateClassroomSubject: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.subjectsCreateClassroomSubject>>, unknown, Parameters<typeof requests.subjectsCreateClassroomSubject>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.subjectsCreateClassroomSubject>>, unknown, Parameters<typeof requests.subjectsCreateClassroomSubject>[0]>(payload => requests.subjectsCreateClassroomSubject(payload), config?.useSubjectsCreateClassroomSubject, options),
        useSubjectsCreateSubject: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.subjectsCreateSubject>>, unknown, Parameters<typeof requests.subjectsCreateSubject>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.subjectsCreateSubject>>, unknown, Parameters<typeof requests.subjectsCreateSubject>[0]>(payload => requests.subjectsCreateSubject(payload), config?.useSubjectsCreateSubject, options),
        useSubjectsUpdate: (id: string, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.subjectsUpdate>>, unknown, Parameters<typeof requests.subjectsUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.subjectsUpdate>>, unknown, Parameters<typeof requests.subjectsUpdate>[0]>(payload => requests.subjectsUpdate(payload, id), config?.useSubjectsUpdate, options),
        useSubscriptionResourceCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.subscriptionResourceCreate>>, unknown, Parameters<typeof requests.subscriptionResourceCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.subscriptionResourceCreate>>, unknown, Parameters<typeof requests.subscriptionResourceCreate>[0]>(payload => requests.subscriptionResourceCreate(payload), config?.useSubscriptionResourceCreate, options),
        useSubscriptionResourceUserSub: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.subscriptionResourceUserSub>>, unknown, Parameters<typeof requests.subscriptionResourceUserSub>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.subscriptionResourceUserSub>>, unknown, Parameters<typeof requests.subscriptionResourceUserSub>[0]>(payload => requests.subscriptionResourceUserSub(payload), config?.useSubscriptionResourceUserSub, options),
        useTopicsCreate: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.topicsCreate>>, unknown, Parameters<typeof requests.topicsCreate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.topicsCreate>>, unknown, Parameters<typeof requests.topicsCreate>[0]>(payload => requests.topicsCreate(payload), config?.useTopicsCreate, options),
        useTopicsDelete: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.topicsDelete>>, unknown, Parameters<typeof requests.topicsDelete>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.topicsDelete>>, unknown, Parameters<typeof requests.topicsDelete>[0]>(payload => requests.topicsDelete(payload), config?.useTopicsDelete, options),
        useTopicsUpdate: (id: UUID, options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.topicsUpdate>>, unknown, Parameters<typeof requests.topicsUpdate>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.topicsUpdate>>, unknown, Parameters<typeof requests.topicsUpdate>[0]>(payload => requests.topicsUpdate(payload, id), config?.useTopicsUpdate, options),
        useUserF: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.userF>>, unknown, unknown, unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.userF>>, unknown, unknown>(() => requests.userF(), config?.useUserF, options),
        useUserCreateStudent: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.userCreateStudent>>, unknown, Parameters<typeof requests.userCreateStudent>[0], unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.userCreateStudent>>, unknown, Parameters<typeof requests.userCreateStudent>[0]>(payload => requests.userCreateStudent(payload), config?.useUserCreateStudent, options),
        useUserCreateTeacher: (options?: Omit<UseMutationOptions<Awaited<ReturnType<typeof requests.userCreateTeacher>>, unknown, unknown, unknown>, "mutationFn">) => useRapiniMutation<Awaited<ReturnType<typeof requests.userCreateTeacher>>, unknown, unknown>(() => requests.userCreateTeacher(), config?.useUserCreateTeacher, options)
    } as const;
}
